"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.alexaforbusiness.create_conference_provider
hub.exec.boto3.client.alexaforbusiness.delete_conference_provider
hub.exec.boto3.client.alexaforbusiness.get_conference_provider
hub.exec.boto3.client.alexaforbusiness.list_conference_providers
hub.exec.boto3.client.alexaforbusiness.update_conference_provider
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, conference_provider_name: Text, conference_provider_type: Text, meeting_setting: Dict, ip_dial_in: Dict = None, pstn_dial_in: Dict = None, client_request_token: Text = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Adds a new conference provider under the user's AWS account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        conference_provider_name(Text): The name of the conference provider.
        conference_provider_type(Text): Represents a type within a list of predefined types.
        ip_dial_in(Dict, optional): The IP endpoint and protocol for calling. Defaults to None.
        pstn_dial_in(Dict, optional): The information for PSTN conferencing. Defaults to None.
        meeting_setting(Dict): The meeting settings for the conference provider.
        client_request_token(Text, optional): The request token of the client. Defaults to None.
        tags(List, optional): The tags to be added to the specified resource. Do not provide system tags. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.alexaforbusiness.conference_provider.present:
                - name: value
                - conference_provider_name: value
                - conference_provider_type: value
                - meeting_setting: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.alexaforbusiness.conference_provider.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.alexaforbusiness.get_conference_provider(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.alexaforbusiness.create_conference_provider(
                ctx,
                
                
                **{"ConferenceProviderName": conference_provider_name, "ConferenceProviderType": conference_provider_type, "IPDialIn": ip_dial_in, "PSTNDialIn": pstn_dial_in, "MeetingSetting": meeting_setting, "ClientRequestToken": client_request_token, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.alexaforbusiness.get_conference_provider(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, conference_provider_arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a conference provider.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        conference_provider_arn(Text): The ARN of the conference provider.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.alexaforbusiness.conference_provider.absent:
                - name: value
                - conference_provider_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.alexaforbusiness.conference_provider.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.alexaforbusiness.get_conference_provider(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.alexaforbusiness.delete_conference_provider(
                ctx,
                
                
                **{"ConferenceProviderArn": conference_provider_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.alexaforbusiness.get_conference_provider(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

