"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.alexaforbusiness.create_user
hub.exec.boto3.client.alexaforbusiness.delete_user
hub.exec.boto3.client.alexaforbusiness.search_users
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, user_id: Text, first_name: Text = None, last_name: Text = None, email: Text = None, client_request_token: Text = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a user.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        user_id(Text): The ARN for the user.
        first_name(Text, optional): The first name for the user. Defaults to None.
        last_name(Text, optional): The last name for the user. Defaults to None.
        email(Text, optional): The email address for the user. Defaults to None.
        client_request_token(Text, optional): A unique, user-specified identifier for this request that ensures idempotency. Defaults to None.
        tags(List, optional): The tags for the user. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.alexaforbusiness.user.present:
                - name: value
                - user_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.alexaforbusiness.user.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.alexaforbusiness.search_users(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.alexaforbusiness.create_user(
                ctx,
                
                
                **{"UserId": user_id, "FirstName": first_name, "LastName": last_name, "Email": email, "ClientRequestToken": client_request_token, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.alexaforbusiness.search_users(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, enrollment_id: Text, user_arn: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a specified user by user ARN and enrollment ARN.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        user_arn(Text, optional): The ARN of the user to delete in the organization. Required. Defaults to None.
        enrollment_id(Text): The ARN of the user's enrollment in the organization. Required.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.alexaforbusiness.user.absent:
                - name: value
                - enrollment_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.alexaforbusiness.user.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.alexaforbusiness.search_users(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.alexaforbusiness.delete_user(
                ctx,
                
                
                **{"UserArn": user_arn, "EnrollmentId": enrollment_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.alexaforbusiness.search_users(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

