"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.amp.create_workspace
hub.exec.boto3.client.amp.delete_workspace
hub.exec.boto3.client.amp.describe_workspace
hub.exec.boto3.client.amp.list_workspaces
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, alias: Text = None, client_token: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new AMP workspace.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        alias(Text, optional): An optional user-assigned alias for this workspace. This alias is for user reference and does
            not need to be unique. Defaults to None.
        client_token(Text, optional): Optional, unique, case-sensitive, user-provided identifier to ensure the idempotency of the
            request. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.amp.workspace.present:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.amp.workspace.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.amp.describe_workspace(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.amp.create_workspace(
                ctx,
                
                
                **{"alias": alias, "clientToken": client_token}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.amp.describe_workspace(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, workspace_id: Text, client_token: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an AMP workspace.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        client_token(Text, optional): Optional, unique, case-sensitive, user-provided identifier to ensure the idempotency of the
            request. Defaults to None.
        workspace_id(Text): The ID of the workspace to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.amp.workspace.absent:
                - name: value
                - workspace_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.amp.workspace.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.amp.describe_workspace(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.amp.delete_workspace(
                ctx,
                
                
                **{"clientToken": client_token, "workspaceId": workspace_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.amp.describe_workspace(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

