"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.amplify.create_webhook
hub.exec.boto3.client.amplify.delete_webhook
hub.exec.boto3.client.amplify.get_webhook
hub.exec.boto3.client.amplify.list_webhooks
hub.exec.boto3.client.amplify.update_webhook
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, app_id: Text, branch_name: Text, description: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
     Creates a new webhook on an Amplify app.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        app_id(Text):  The unique ID for an Amplify app.
        branch_name(Text):  The name for a branch that is part of an Amplify app.
        description(Text, optional):  The description for a webhook. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.amplify.webhook.present:
                - name: value
                - app_id: value
                - branch_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.amplify.webhook.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.amplify.get_webhook(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.amplify.create_webhook(
                ctx,
                
                
                **{"appId": app_id, "branchName": branch_name, "description": description}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.amplify.get_webhook(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, webhook_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
     Deletes a webhook.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        webhook_id(Text):  The unique ID for a webhook.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.amplify.webhook.absent:
                - name: value
                - webhook_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.amplify.webhook.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.amplify.get_webhook(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.amplify.delete_webhook(
                ctx,
                
                
                **{"webhookId": webhook_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.amplify.get_webhook(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

