"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.amplifybackend.clone_backend
hub.exec.boto3.client.amplifybackend.create_backend
hub.exec.boto3.client.amplifybackend.delete_backend
hub.exec.boto3.client.amplifybackend.get_backend
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, app_id: Text, app_name: Text, backend_environment_name: Text, resource_config: Dict = None, resource_name: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    This operation creates a backend for an Amplify app. Backends are automatically created at the time of app
    creation.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        app_id(Text): The app ID.
        app_name(Text): The name of the app.
        backend_environment_name(Text): The name of the backend environment.
        resource_config(Dict, optional): The resource configuration for the create backend request. Defaults to None.
        resource_name(Text, optional): The name of the resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.amplifybackend.backend.present:
                - name: value
                - app_id: value
                - app_name: value
                - backend_environment_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.amplifybackend.backend.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.amplifybackend.get_backend(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.amplifybackend.create_backend(
                ctx,
                
                
                **{"AppId": app_id, "AppName": app_name, "BackendEnvironmentName": backend_environment_name, "ResourceConfig": resource_config, "ResourceName": resource_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.amplifybackend.get_backend(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, app_id: Text, backend_environment_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Removes an existing environment from your Amplify project.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        app_id(Text): The app ID.
        backend_environment_name(Text): The name of the backend environment.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.amplifybackend.backend.absent:
                - name: value
                - app_id: value
                - backend_environment_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.amplifybackend.backend.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.amplifybackend.get_backend(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.amplifybackend.delete_backend(
                ctx,
                
                
                **{"AppId": app_id, "BackendEnvironmentName": backend_environment_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.amplifybackend.get_backend(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

