"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.amplifybackend.create_backend_api
hub.exec.boto3.client.amplifybackend.delete_backend_api
hub.exec.boto3.client.amplifybackend.get_backend_api
hub.exec.boto3.client.amplifybackend.update_backend_api
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, app_id: Text, backend_environment_name: Text, resource_config: Dict, resource_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new backend API resource.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        app_id(Text): The app ID.
        backend_environment_name(Text): The name of the backend environment.
        resource_config(Dict): The resource configuration for this request.
        resource_name(Text): The name of this resource.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.amplifybackend.backend_api.present:
                - name: value
                - app_id: value
                - backend_environment_name: value
                - resource_config: value
                - resource_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.amplifybackend.backend_api.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.amplifybackend.get_backend_api(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.amplifybackend.create_backend_api(
                ctx,
                
                
                **{"AppId": app_id, "BackendEnvironmentName": backend_environment_name, "ResourceConfig": resource_config, "ResourceName": resource_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.amplifybackend.get_backend_api(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, app_id: Text, backend_environment_name: Text, resource_name: Text, resource_config: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an existing backend API resource.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        app_id(Text): The app ID.
        backend_environment_name(Text): The name of the backend environment.
        resource_config(Dict, optional): Defines the resource configuration for the data model in your Amplify project. Defaults to None.
        resource_name(Text): The name of this resource.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.amplifybackend.backend_api.absent:
                - name: value
                - app_id: value
                - backend_environment_name: value
                - resource_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.amplifybackend.backend_api.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.amplifybackend.get_backend_api(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.amplifybackend.delete_backend_api(
                ctx,
                
                
                **{"AppId": app_id, "BackendEnvironmentName": backend_environment_name, "ResourceConfig": resource_config, "ResourceName": resource_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.amplifybackend.get_backend_api(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

