"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.amplifybackend.create_token
hub.exec.boto3.client.amplifybackend.delete_token
hub.exec.boto3.client.amplifybackend.get_token
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, app_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Generates a one-time challenge code to authenticate a user into your Amplify Admin UI.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        app_id(Text): The app ID.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.amplifybackend.token.present:
                - name: value
                - app_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.amplifybackend.token.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.amplifybackend.get_token(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.amplifybackend.create_token(
                ctx,
                
                
                **{"AppId": app_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.amplifybackend.get_token(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, app_id: Text, session_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the challenge token based on the given appId and sessionId.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        app_id(Text): The app ID.
        session_id(Text): The session ID.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.amplifybackend.token.absent:
                - name: value
                - app_id: value
                - session_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.amplifybackend.token.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.amplifybackend.get_token(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.amplifybackend.delete_token(
                ctx,
                
                
                **{"AppId": app_id, "SessionId": session_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.amplifybackend.get_token(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

