"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.apigateway.create_documentation_part
hub.exec.boto3.client.apigateway.delete_documentation_part
hub.exec.boto3.client.apigateway.get_documentation_parts
hub.exec.boto3.client.apigateway.import_documentation_parts
hub.exec.boto3.client.apigateway.update_documentation_part
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, rest_api_id: Text, location: Dict, properties: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        rest_api_id(Text): [Required] The string identifier of the associated RestApi.
        location(Dict): [Required] The location of the targeted API entity of the to-be-created documentation part.
        properties(Text): [Required] The new documentation content map of the targeted API entity. Enclosed key-value
            pairs are API-specific, but only OpenAPI-compliant key-value pairs can be exported and, hence,
            published.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.apigateway.documentation_part.present:
                - name: value
                - rest_api_id: value
                - location: value
                - properties: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.apigateway.documentation_part.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.apigateway.get_documentation_parts(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.apigateway.create_documentation_part(
                ctx,
                
                
                **{"restApiId": rest_api_id, "location": location, "properties": properties}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.apigateway.get_documentation_parts(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, rest_api_id: Text, documentation_part_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        rest_api_id(Text): [Required] The string identifier of the associated RestApi.
        documentation_part_id(Text): [Required] The identifier of the to-be-deleted documentation part.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.apigateway.documentation_part.absent:
                - name: value
                - rest_api_id: value
                - documentation_part_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.apigateway.documentation_part.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.apigateway.get_documentation_parts(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.apigateway.delete_documentation_part(
                ctx,
                
                
                **{"restApiId": rest_api_id, "documentationPartId": documentation_part_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.apigateway.get_documentation_parts(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

