"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.apigateway.create_documentation_version
hub.exec.boto3.client.apigateway.delete_documentation_version
hub.exec.boto3.client.apigateway.get_documentation_versions
hub.exec.boto3.client.apigateway.update_documentation_version
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, rest_api_id: Text, documentation_version: Text, stage_name: Text = None, description: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        rest_api_id(Text): [Required] The string identifier of the associated RestApi.
        documentation_version(Text): [Required] The version identifier of the new snapshot.
        stage_name(Text, optional): The stage name to be associated with the new documentation snapshot. Defaults to None.
        description(Text, optional): A description about the new documentation snapshot. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.apigateway.documentation_version.present:
                - name: value
                - rest_api_id: value
                - documentation_version: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.apigateway.documentation_version.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.apigateway.get_documentation_versions(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.apigateway.create_documentation_version(
                ctx,
                
                
                **{"restApiId": rest_api_id, "documentationVersion": documentation_version, "stageName": stage_name, "description": description}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.apigateway.get_documentation_versions(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, rest_api_id: Text, documentation_version: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        rest_api_id(Text): [Required] The string identifier of the associated RestApi.
        documentation_version(Text): [Required] The version identifier of a to-be-deleted documentation snapshot.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.apigateway.documentation_version.absent:
                - name: value
                - rest_api_id: value
                - documentation_version: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.apigateway.documentation_version.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.apigateway.get_documentation_versions(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.apigateway.delete_documentation_version(
                ctx,
                
                
                **{"restApiId": rest_api_id, "documentationVersion": documentation_version}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.apigateway.get_documentation_versions(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

