"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.apigatewayv2.create_api_mapping
hub.exec.boto3.client.apigatewayv2.delete_api_mapping
hub.exec.boto3.client.apigatewayv2.get_api_mappings
hub.exec.boto3.client.apigatewayv2.update_api_mapping
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, api_id: Text, domain_name: Text, stage: Text, api_mapping_key: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an API mapping.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        api_id(Text): The API identifier.
        api_mapping_key(Text, optional): The API mapping key. Defaults to None.
        domain_name(Text): The domain name.
        stage(Text): The API stage.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.apigatewayv2.api_mapping.present:
                - name: value
                - api_id: value
                - domain_name: value
                - stage: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.apigatewayv2.api_mapping.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.apigatewayv2.get_api_mappings(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.apigatewayv2.create_api_mapping(
                ctx,
                
                
                **{"ApiId": api_id, "ApiMappingKey": api_mapping_key, "DomainName": domain_name, "Stage": stage}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.apigatewayv2.get_api_mappings(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, api_mapping_id: Text, domain_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an API mapping.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        api_mapping_id(Text): The API mapping identifier.
        domain_name(Text): The domain name.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.apigatewayv2.api_mapping.absent:
                - name: value
                - api_mapping_id: value
                - domain_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.apigatewayv2.api_mapping.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.apigatewayv2.get_api_mappings(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.apigatewayv2.delete_api_mapping(
                ctx,
                
                
                **{"ApiMappingId": api_mapping_id, "DomainName": domain_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.apigatewayv2.get_api_mappings(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

