"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.apigatewayv2.create_vpc_link
hub.exec.boto3.client.apigatewayv2.delete_vpc_link
hub.exec.boto3.client.apigatewayv2.get_vpc_links
hub.exec.boto3.client.apigatewayv2.update_vpc_link
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, subnet_ids: List, security_group_ids: List = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a VPC link.

    Args:
        name(Text): The name of the VPC link.
        security_group_ids(List, optional): A list of security group IDs for the VPC link. Defaults to None.
        subnet_ids(List): A list of subnet IDs to include in the VPC link.
        tags(Dict, optional): A list of tags. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.apigatewayv2.vpc_link.present:
                - name: value
                - subnet_ids: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.apigatewayv2.vpc_link.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.apigatewayv2.get_vpc_links(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.apigatewayv2.create_vpc_link(
                ctx,
                
                
                **{"Name": name, "SecurityGroupIds": security_group_ids, "SubnetIds": subnet_ids, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.apigatewayv2.get_vpc_links(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, vpc_link_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a VPC link.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        vpc_link_id(Text): The ID of the VPC link.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.apigatewayv2.vpc_link.absent:
                - name: value
                - vpc_link_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.apigatewayv2.vpc_link.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.apigatewayv2.get_vpc_links(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.apigatewayv2.delete_vpc_link(
                ctx,
                
                
                **{"VpcLinkId": vpc_link_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.apigatewayv2.get_vpc_links(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

