"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.appconfig.create_application
hub.exec.boto3.client.appconfig.delete_application
hub.exec.boto3.client.appconfig.get_application
hub.exec.boto3.client.appconfig.list_applications
hub.exec.boto3.client.appconfig.update_application
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, description: Text = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    An application in AppConfig is a logical unit of code that provides capabilities for your customers. For
    example, an application can be a microservice that runs on Amazon EC2 instances, a mobile application installed
    by your users, a serverless application using Amazon API Gateway and AWS Lambda, or any system you run on behalf
    of others.

    Args:
        name(Text): A name for the application.
        description(Text, optional): A description of the application. Defaults to None.
        tags(Dict, optional): Metadata to assign to the application. Tags help organize and categorize your AppConfig
            resources. Each tag consists of a key and an optional value, both of which you define. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.appconfig.application.present:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.appconfig.application.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.appconfig.get_application(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.appconfig.create_application(
                ctx,
                
                
                **{"Name": name, "Description": description, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.appconfig.get_application(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, application_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Delete an application. Deleting an application does not delete a configuration from a host.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        application_id(Text): The ID of the application to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.appconfig.application.absent:
                - name: value
                - application_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.appconfig.application.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.appconfig.get_application(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.appconfig.delete_application(
                ctx,
                
                
                **{"ApplicationId": application_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.appconfig.get_application(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

