"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.application_insights.create_application
hub.exec.boto3.client.application_insights.delete_application
hub.exec.boto3.client.application_insights.describe_application
hub.exec.boto3.client.application_insights.list_applications
hub.exec.boto3.client.application_insights.update_application
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, resource_group_name: Text, ops_center_enabled: bool = None, cwe_monitor_enabled: bool = None, ops_item_sns_topic_arn: Text = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Adds an application that is created from a resource group.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        resource_group_name(Text): The name of the resource group.
        ops_center_enabled(bool, optional):  When set to true, creates opsItems for any problems detected on an application. Defaults to None.
        cwe_monitor_enabled(bool, optional):  Indicates whether Application Insights can listen to CloudWatch events for the application
            resources, such as instance terminated, failed deployment, and others. Defaults to None.
        ops_item_sns_topic_arn(Text, optional):  The SNS topic provided to Application Insights that is associated to the created opsItem.
            Allows you to receive notifications for updates to the opsItem. Defaults to None.
        tags(List, optional): List of tags to add to the application. tag key (Key) and an associated tag value (Value). The
            maximum length of a tag key is 128 characters. The maximum length of a tag value is 256
            characters. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.application_insights.application.present:
                - name: value
                - resource_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.application_insights.application.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.application_insights.describe_application(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.application_insights.create_application(
                ctx,
                
                
                **{"ResourceGroupName": resource_group_name, "OpsCenterEnabled": ops_center_enabled, "CWEMonitorEnabled": cwe_monitor_enabled, "OpsItemSNSTopicArn": ops_item_sns_topic_arn, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.application_insights.describe_application(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, resource_group_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Removes the specified application from monitoring. Does not delete the application.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        resource_group_name(Text): The name of the resource group.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.application_insights.application.absent:
                - name: value
                - resource_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.application_insights.application.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.application_insights.describe_application(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.application_insights.delete_application(
                ctx,
                
                
                **{"ResourceGroupName": resource_group_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.application_insights.describe_application(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

