"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.application_insights.create_component
hub.exec.boto3.client.application_insights.delete_component
hub.exec.boto3.client.application_insights.describe_component
hub.exec.boto3.client.application_insights.list_components
hub.exec.boto3.client.application_insights.update_component
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, resource_group_name: Text, component_name: Text, resource_list: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a custom component by grouping similar standalone instances to monitor.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        resource_group_name(Text): The name of the resource group.
        component_name(Text): The name of the component.
        resource_list(List): The list of resource ARNs that belong to the component.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.application_insights.component.present:
                - name: value
                - resource_group_name: value
                - component_name: value
                - resource_list: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.application_insights.component.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.application_insights.describe_component(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.application_insights.create_component(
                ctx,
                
                
                **{"ResourceGroupName": resource_group_name, "ComponentName": component_name, "ResourceList": resource_list}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.application_insights.describe_component(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, resource_group_name: Text, component_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Ungroups a custom component. When you ungroup custom components, all applicable monitors that are set up for the
    component are removed and the instances revert to their standalone status.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        resource_group_name(Text): The name of the resource group.
        component_name(Text): The name of the component.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.application_insights.component.absent:
                - name: value
                - resource_group_name: value
                - component_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.application_insights.component.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.application_insights.describe_component(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.application_insights.delete_component(
                ctx,
                
                
                **{"ResourceGroupName": resource_group_name, "ComponentName": component_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.application_insights.describe_component(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

