"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.athena.create_prepared_statement
hub.exec.boto3.client.athena.delete_prepared_statement
hub.exec.boto3.client.athena.get_prepared_statement
hub.exec.boto3.client.athena.list_prepared_statements
hub.exec.boto3.client.athena.update_prepared_statement
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, statement_name: Text, work_group: Text, query_statement: Text, description: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a prepared statement for use with SQL queries in Athena.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        statement_name(Text): The name of the prepared statement.
        work_group(Text): The name of the workgroup to which the prepared statement belongs.
        query_statement(Text): The query string for the prepared statement.
        description(Text, optional): The description of the prepared statement. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.athena.prepared_statement.present:
                - name: value
                - statement_name: value
                - work_group: value
                - query_statement: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.athena.prepared_statement.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.athena.get_prepared_statement(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.athena.create_prepared_statement(
                ctx,
                
                
                **{"StatementName": statement_name, "WorkGroup": work_group, "QueryStatement": query_statement, "Description": description}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.athena.get_prepared_statement(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, statement_name: Text, work_group: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the prepared statement with the specified name from the specified workgroup.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        statement_name(Text): The name of the prepared statement to delete.
        work_group(Text): The workgroup to which the statement to be deleted belongs.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.athena.prepared_statement.absent:
                - name: value
                - statement_name: value
                - work_group: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.athena.prepared_statement.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.athena.get_prepared_statement(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.athena.delete_prepared_statement(
                ctx,
                
                
                **{"StatementName": statement_name, "WorkGroup": work_group}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.athena.get_prepared_statement(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

