"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.auditmanager.create_assessment_report
hub.exec.boto3.client.auditmanager.delete_assessment_report
hub.exec.boto3.client.auditmanager.list_assessment_reports
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, assessment_id: Text, description: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
     Creates an assessment report for the specified assessment.

    Args:
        name(Text):  The name of the new assessment report.
        description(Text, optional):  The description of the assessment report. Defaults to None.
        assessment_id(Text):  The identifier for the specified assessment.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.auditmanager.assessment_report.present:
                - name: value
                - assessment_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.auditmanager.assessment_report.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.auditmanager.list_assessment_reports(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.auditmanager.create_assessment_report(
                ctx,
                
                
                **{"Name": name, "description": description, "assessmentId": assessment_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.auditmanager.list_assessment_reports(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, assessment_id: Text, assessment_report_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
     Deletes an assessment report from an assessment in Audit Manager.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        assessment_id(Text):  The identifier for the specified assessment.
        assessment_report_id(Text):  The unique identifier for the assessment report.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.auditmanager.assessment_report.absent:
                - name: value
                - assessment_id: value
                - assessment_report_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.auditmanager.assessment_report.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.auditmanager.list_assessment_reports(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.auditmanager.delete_assessment_report(
                ctx,
                
                
                **{"assessmentId": assessment_id, "assessmentReportId": assessment_report_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.auditmanager.list_assessment_reports(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

