"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.auditmanager.create_control
hub.exec.boto3.client.auditmanager.delete_control
hub.exec.boto3.client.auditmanager.get_control
hub.exec.boto3.client.auditmanager.list_controls
hub.exec.boto3.client.auditmanager.update_control
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, control_mapping_sources: List, description: Text = None, testing_information: Text = None, action_plan_title: Text = None, action_plan_instructions: Text = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
     Creates a new custom control in Audit Manager.

    Args:
        name(Text):  The name of the control.
        description(Text, optional):  The description of the control. Defaults to None.
        testing_information(Text, optional):  The steps to follow to determine if the control has been satisfied. Defaults to None.
        action_plan_title(Text, optional):  The title of the action plan for remediating the control. Defaults to None.
        action_plan_instructions(Text, optional):  The recommended actions to carry out if the control is not fulfilled. Defaults to None.
        control_mapping_sources(List):  The data mapping sources for the specified control.
        tags(Dict, optional):  The tags associated with the control. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.auditmanager.control.present:
                - name: value
                - control_mapping_sources: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.auditmanager.control.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.auditmanager.get_control(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.auditmanager.create_control(
                ctx,
                
                
                **{"Name": name, "description": description, "testingInformation": testing_information, "actionPlanTitle": action_plan_title, "actionPlanInstructions": action_plan_instructions, "controlMappingSources": control_mapping_sources, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.auditmanager.get_control(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, control_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
     Deletes a custom control in Audit Manager.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        control_id(Text):  The identifier for the specified control.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.auditmanager.control.absent:
                - name: value
                - control_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.auditmanager.control.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.auditmanager.get_control(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.auditmanager.delete_control(
                ctx,
                
                
                **{"controlId": control_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.auditmanager.get_control(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

