"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ce.create_anomaly_subscription
hub.exec.boto3.client.ce.delete_anomaly_subscription
hub.exec.boto3.client.ce.get_anomaly_subscriptions
hub.exec.boto3.client.ce.update_anomaly_subscription
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, anomaly_subscription: Dict)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Adds a subscription to a cost anomaly detection monitor. You can use each subscription to define subscribers
    with email or SNS notifications. Email subscribers can set a dollar threshold and a time frequency for receiving
    notifications.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        anomaly_subscription(Dict): The cost anomaly subscription object that you want to create.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ce.anomaly_subscription.present:
                - name: value
                - anomaly_subscription: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ce.anomaly_subscription.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ce.get_anomaly_subscriptions(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ce.create_anomaly_subscription(
                ctx,
                
                
                **{"AnomalySubscription": anomaly_subscription}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ce.get_anomaly_subscriptions(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, subscription_arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a cost anomaly subscription.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        subscription_arn(Text): The unique identifier of the cost anomaly subscription that you want to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ce.anomaly_subscription.absent:
                - name: value
                - subscription_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ce.anomaly_subscription.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ce.get_anomaly_subscriptions(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ce.delete_anomaly_subscription(
                ctx,
                
                
                **{"SubscriptionArn": subscription_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ce.get_anomaly_subscriptions(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

