"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.chime.create_app_instance_user
hub.exec.boto3.client.chime.delete_app_instance_user
hub.exec.boto3.client.chime.describe_app_instance_user
hub.exec.boto3.client.chime.list_app_instance_users
hub.exec.boto3.client.chime.update_app_instance_user
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, app_instance_arn: Text, app_instance_user_id: Text, client_request_token: Text, metadata: Text = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a user under an Amazon Chime AppInstance. The request consists of a unique appInstanceUserId and Name
    for that user.

    Args:
        name(Text): The user's name.
        app_instance_arn(Text): The ARN of the AppInstance request.
        app_instance_user_id(Text): The user ID of the AppInstance.
        metadata(Text, optional): The request's metadata. Limited to a 1KB string in UTF-8. Defaults to None.
        client_request_token(Text): The token assigned to the user requesting an AppInstance.
        tags(List, optional): Tags assigned to the AppInstanceUser. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.chime.app_instance_user.present:
                - name: value
                - app_instance_arn: value
                - app_instance_user_id: value
                - client_request_token: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.chime.app_instance_user.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.chime.describe_app_instance_user(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.chime.create_app_instance_user(
                ctx,
                
                
                **{"Name": name, "AppInstanceArn": app_instance_arn, "AppInstanceUserId": app_instance_user_id, "Metadata": metadata, "ClientRequestToken": client_request_token, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.chime.describe_app_instance_user(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, app_instance_user_arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an AppInstanceUser.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        app_instance_user_arn(Text): The ARN of the user request being deleted.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.chime.app_instance_user.absent:
                - name: value
                - app_instance_user_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.chime.app_instance_user.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.chime.describe_app_instance_user(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.chime.delete_app_instance_user(
                ctx,
                
                
                **{"AppInstanceUserArn": app_instance_user_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.chime.describe_app_instance_user(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

