"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.chime.delete_events_configuration
hub.exec.boto3.client.chime.get_events_configuration
hub.exec.boto3.client.chime.put_events_configuration
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, account_id: Text, bot_id: Text, outbound_events_https_endpoint: Text = None, lambda_function_arn: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an events configuration that allows a bot to receive outgoing events sent by Amazon Chime. Choose either
    an HTTPS endpoint or a Lambda function ARN. For more information, see Bot.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        account_id(Text): The Amazon Chime account ID.
        bot_id(Text): The bot ID.
        outbound_events_https_endpoint(Text, optional): HTTPS endpoint that allows the bot to receive outgoing events. Defaults to None.
        lambda_function_arn(Text, optional): Lambda function ARN that allows the bot to receive outgoing events. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.chime.events_configuration.present:
                - name: value
                - account_id: value
                - bot_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.chime.events_configuration.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.chime.get_events_configuration(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.chime.put_events_configuration(
                ctx,
                
                
                **{"AccountId": account_id, "BotId": bot_id, "OutboundEventsHTTPSEndpoint": outbound_events_https_endpoint, "LambdaFunctionArn": lambda_function_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.chime.get_events_configuration(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, account_id: Text, bot_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the events configuration that allows a bot to receive outgoing events.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        account_id(Text): The Amazon Chime account ID.
        bot_id(Text): The bot ID.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.chime.events_configuration.absent:
                - name: value
                - account_id: value
                - bot_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.chime.events_configuration.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.chime.get_events_configuration(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.chime.delete_events_configuration(
                ctx,
                
                
                **{"AccountId": account_id, "BotId": bot_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.chime.get_events_configuration(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

