"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.chime.create_sip_media_application
hub.exec.boto3.client.chime.delete_sip_media_application
hub.exec.boto3.client.chime.get_sip_media_application
hub.exec.boto3.client.chime.list_sip_media_applications
hub.exec.boto3.client.chime.update_sip_media_application
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, aws_region: Text, endpoints: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a SIP media application.

    Args:
        name(Text): The SIP media application name.
        aws_region(Text): The AWS Region assigned to the SIP media application.
        endpoints(List): List of endpoints (Lambda Amazon Resource Names) specified for the SIP media application.
            Currently, only one endpoint is supported.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.chime.sip_media_application.present:
                - name: value
                - aws_region: value
                - endpoints: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.chime.sip_media_application.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.chime.get_sip_media_application(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.chime.create_sip_media_application(
                ctx,
                
                
                **{"Name": name, "AwsRegion": aws_region, "Endpoints": endpoints}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.chime.get_sip_media_application(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, sip_media_application_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a SIP media application.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        sip_media_application_id(Text): The SIP media application ID.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.chime.sip_media_application.absent:
                - name: value
                - sip_media_application_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.chime.sip_media_application.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.chime.get_sip_media_application(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.chime.delete_sip_media_application(
                ctx,
                
                
                **{"SipMediaApplicationId": sip_media_application_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.chime.get_sip_media_application(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

