"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.chime.delete_voice_connector_termination_credentials
hub.exec.boto3.client.chime.list_voice_connector_termination_credentials
hub.exec.boto3.client.chime.put_voice_connector_termination_credentials
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, voice_connector_id: Text, credentials: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Adds termination SIP credentials for the specified Amazon Chime Voice Connector.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        voice_connector_id(Text): The Amazon Chime Voice Connector ID.
        credentials(List, optional): The termination SIP credentials. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.chime.voice_connector_termination_credential.present:
                - name: value
                - voice_connector_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.chime.voice_connector_termination_credential.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.chime.list_voice_connector_termination_credentials(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.chime.put_voice_connector_termination_credentials(
                ctx,
                
                
                **{"VoiceConnectorId": voice_connector_id, "Credentials": credentials}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.chime.list_voice_connector_termination_credentials(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, voice_connector_id: Text, usernames: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the specified SIP credentials used by your equipment to authenticate during call termination.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        voice_connector_id(Text): The Amazon Chime Voice Connector ID.
        usernames(List): The RFC2617 compliant username associated with the SIP credentials, in US-ASCII format.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.chime.voice_connector_termination_credential.absent:
                - name: value
                - voice_connector_id: value
                - usernames: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.chime.voice_connector_termination_credential.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.chime.list_voice_connector_termination_credentials(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.chime.delete_voice_connector_termination_credentials(
                ctx,
                
                
                **{"VoiceConnectorId": voice_connector_id, "Usernames": usernames}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.chime.list_voice_connector_termination_credentials(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

