"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.cloudfront.create_field_level_encryption_profile
hub.exec.boto3.client.cloudfront.delete_field_level_encryption_profile
hub.exec.boto3.client.cloudfront.get_field_level_encryption_profile
hub.exec.boto3.client.cloudfront.list_field_level_encryption_profiles
hub.exec.boto3.client.cloudfront.update_field_level_encryption_profile
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, field_level_encryption_profile_config: Dict)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Create a field-level encryption profile.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        field_level_encryption_profile_config(Dict): The request to create a field-level encryption profile.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.cloudfront.field_level_encryption_profile.present:
                - name: value
                - field_level_encryption_profile_config: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.cloudfront.field_level_encryption_profile.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.cloudfront.get_field_level_encryption_profile(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.cloudfront.create_field_level_encryption_profile(
                ctx,
                
                
                **{"FieldLevelEncryptionProfileConfig": field_level_encryption_profile_config}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.cloudfront.get_field_level_encryption_profile(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, id_: Text, if_match: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Remove a field-level encryption profile.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        id_(Text): Request the ID of the profile you want to delete from CloudFront.
        if_match(Text, optional): The value of the ETag header that you received when retrieving the profile to delete. For
            example: E2QWRUHAPOMQZL. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.cloudfront.field_level_encryption_profile.absent:
                - name: value
                - id_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.cloudfront.field_level_encryption_profile.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.cloudfront.get_field_level_encryption_profile(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.cloudfront.delete_field_level_encryption_profile(
                ctx,
                
                
                **{"Id": id_, "IfMatch": if_match}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.cloudfront.get_field_level_encryption_profile(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

