"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.cloudwatch.delete_insight_rules
hub.exec.boto3.client.cloudwatch.describe_insight_rules
hub.exec.boto3.client.cloudwatch.disable_insight_rules
hub.exec.boto3.client.cloudwatch.enable_insight_rules
hub.exec.boto3.client.cloudwatch.put_insight_rule
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, rule_names: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Enables the specified Contributor Insights rules. When rules are enabled, they immediately begin analyzing log
    data.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        rule_names(List): An array of the rule names to enable. If you need to find out the names of your rules, use
            DescribeInsightRules.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.cloudwatch.insight_rule.present:
                - name: value
                - rule_names: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.cloudwatch.insight_rule.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.cloudwatch.describe_insight_rules(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.cloudwatch.enable_insight_rules(
                ctx,
                
                
                **{"RuleNames": rule_names}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.cloudwatch.describe_insight_rules(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, rule_names: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Permanently deletes the specified Contributor Insights rules. If you create a rule, delete it, and then re-
    create it with the same name, historical data from the first time the rule was created might not be available.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        rule_names(List): An array of the rule names to delete. If you need to find out the names of your rules, use
            DescribeInsightRules.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.cloudwatch.insight_rule.absent:
                - name: value
                - rule_names: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.cloudwatch.insight_rule.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.cloudwatch.describe_insight_rules(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.cloudwatch.delete_insight_rules(
                ctx,
                
                
                **{"RuleNames": rule_names}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.cloudwatch.describe_insight_rules(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

