"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.codecommit.create_branch
hub.exec.boto3.client.codecommit.delete_branch
hub.exec.boto3.client.codecommit.get_branch
hub.exec.boto3.client.codecommit.list_branches
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, repository_name: Text, branch_name: Text, commit_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a branch in a repository and points the branch to a commit.  Calling the create branch operation does
    not set a repository's default branch. To do this, call the update default branch operation.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        repository_name(Text): The name of the repository in which you want to create the new branch.
        branch_name(Text): The name of the new branch to create.
        commit_id(Text): The ID of the commit to point the new branch to.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.codecommit.branch.present:
                - name: value
                - repository_name: value
                - branch_name: value
                - commit_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.codecommit.branch.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.codecommit.get_branch(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.codecommit.create_branch(
                ctx,
                
                
                **{"repositoryName": repository_name, "branchName": branch_name, "commitId": commit_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.codecommit.get_branch(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, repository_name: Text, branch_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a branch from a repository, unless that branch is the default branch for the repository.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        repository_name(Text): The name of the repository that contains the branch to be deleted.
        branch_name(Text): The name of the branch to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.codecommit.branch.absent:
                - name: value
                - repository_name: value
                - branch_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.codecommit.branch.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.codecommit.get_branch(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.codecommit.delete_branch(
                ctx,
                
                
                **{"repositoryName": repository_name, "branchName": branch_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.codecommit.get_branch(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

