"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.codepipeline.create_pipeline
hub.exec.boto3.client.codepipeline.delete_pipeline
hub.exec.boto3.client.codepipeline.get_pipeline
hub.exec.boto3.client.codepipeline.list_pipelines
hub.exec.boto3.client.codepipeline.update_pipeline
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, pipeline: Dict, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a pipeline.  In the pipeline structure, you must include either artifactStore or artifactStores in your
    pipeline, but you cannot use both. If you create a cross-region action in your pipeline, you must use
    artifactStores.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        pipeline(Dict): Represents the structure of actions and stages to be performed in the pipeline.
        tags(List, optional): The tags for the pipeline. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.codepipeline.pipeline.present:
                - name: value
                - pipeline: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.codepipeline.pipeline.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.codepipeline.get_pipeline(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.codepipeline.create_pipeline(
                ctx,
                
                
                **{"pipeline": pipeline, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.codepipeline.get_pipeline(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the specified pipeline.

    Args:
        name(Text): The name of the pipeline to be deleted.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.codepipeline.pipeline.absent:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.codepipeline.pipeline.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.codepipeline.get_pipeline(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.codepipeline.delete_pipeline(
                ctx,
                
                
                **{"Name": name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.codepipeline.get_pipeline(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

