"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.connect.associate_routing_profile_queues
hub.exec.boto3.client.connect.disassociate_routing_profile_queues
hub.exec.boto3.client.connect.list_routing_profile_queues
hub.exec.boto3.client.connect.update_routing_profile_queues
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, instance_id: Text, routing_profile_id: Text, queue_configs: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Associates a set of queues with a routing profile.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        instance_id(Text): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the
            instance.
        routing_profile_id(Text): The identifier of the routing profile.
        queue_configs(List): The queues to associate with this routing profile.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.connect.routing_profile_queue.present:
                - name: value
                - instance_id: value
                - routing_profile_id: value
                - queue_configs: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.connect.routing_profile_queue.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.connect.list_routing_profile_queues(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.connect.associate_routing_profile_queues(
                ctx,
                
                
                **{"InstanceId": instance_id, "RoutingProfileId": routing_profile_id, "QueueConfigs": queue_configs}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.connect.list_routing_profile_queues(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, instance_id: Text, routing_profile_id: Text, queue_references: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Disassociates a set of queues from a routing profile.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        instance_id(Text): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the
            instance.
        routing_profile_id(Text): The identifier of the routing profile.
        queue_references(List): The queues to disassociate from this routing profile.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.connect.routing_profile_queue.absent:
                - name: value
                - instance_id: value
                - routing_profile_id: value
                - queue_references: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.connect.routing_profile_queue.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.connect.list_routing_profile_queues(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.connect.disassociate_routing_profile_queues(
                ctx,
                
                
                **{"InstanceId": instance_id, "RoutingProfileId": routing_profile_id, "QueueReferences": queue_references}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.connect.list_routing_profile_queues(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

