"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.connect.create_user_hierarchy_group
hub.exec.boto3.client.connect.delete_user_hierarchy_group
hub.exec.boto3.client.connect.describe_user_hierarchy_group
hub.exec.boto3.client.connect.list_user_hierarchy_groups
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, instance_id: Text, parent_group_id: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new user hierarchy group.

    Args:
        name(Text): The name of the user hierarchy group. Must not be more than 100 characters.
        parent_group_id(Text, optional): The identifier for the parent hierarchy group. The user hierarchy is created at level one if the
            parent group ID is null. Defaults to None.
        instance_id(Text): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the
            instance.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.connect.user_hierarchy_group.present:
                - name: value
                - instance_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.connect.user_hierarchy_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.connect.describe_user_hierarchy_group(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.connect.create_user_hierarchy_group(
                ctx,
                
                
                **{"Name": name, "ParentGroupId": parent_group_id, "InstanceId": instance_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.connect.describe_user_hierarchy_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, hierarchy_group_id: Text, instance_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an existing user hierarchy group. It must not be associated with any agents or have any active child
    groups.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        hierarchy_group_id(Text): The identifier of the hierarchy group.
        instance_id(Text): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the
            instance.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.connect.user_hierarchy_group.absent:
                - name: value
                - hierarchy_group_id: value
                - instance_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.connect.user_hierarchy_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.connect.describe_user_hierarchy_group(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.connect.delete_user_hierarchy_group(
                ctx,
                
                
                **{"HierarchyGroupId": hierarchy_group_id, "InstanceId": instance_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.connect.describe_user_hierarchy_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

