"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.cur.delete_report_definition
hub.exec.boto3.client.cur.describe_report_definitions
hub.exec.boto3.client.cur.modify_report_definition
hub.exec.boto3.client.cur.put_report_definition
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, report_definition: Dict)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new report using the description that you provide.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        report_definition(Dict): Represents the output of the PutReportDefinition operation. The content consists of the detailed
            metadata and data file information.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.cur.report_definition.present:
                - name: value
                - report_definition: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.cur.report_definition.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.cur.describe_report_definitions(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.cur.put_report_definition(
                ctx,
                
                
                **{"ReportDefinition": report_definition}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.cur.describe_report_definitions(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, report_name: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the specified report.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        report_name(Text, optional): The name of the report that you want to delete. The name must be unique, is case sensitive, and
            can't include spaces. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.cur.report_definition.absent:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.cur.report_definition.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.cur.describe_report_definitions(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.cur.delete_report_definition(
                ctx,
                
                
                **{"ReportName": report_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.cur.describe_report_definitions(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

