"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.dataexchange.cancel_job
hub.exec.boto3.client.dataexchange.create_job
hub.exec.boto3.client.dataexchange.get_job
hub.exec.boto3.client.dataexchange.list_jobs
hub.exec.boto3.client.dataexchange.start_job
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, details: Dict, type_: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    This operation creates a job.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        details(Dict): The details for the CreateJob request.
        type_(Text): The type of job to be created.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.dataexchange.job.present:
                - name: value
                - details: value
                - type_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.dataexchange.job.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.dataexchange.get_job(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.dataexchange.create_job(
                ctx,
                
                
                **{"Details": details, "Type": type_}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.dataexchange.get_job(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, job_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    This operation cancels a job. Jobs can be cancelled only when they are in the WAITING state.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        job_id(Text): The unique identifier for a job.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.dataexchange.job.absent:
                - name: value
                - job_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.dataexchange.job.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.dataexchange.get_job(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.dataexchange.cancel_job(
                ctx,
                
                
                **{"JobId": job_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.dataexchange.get_job(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

