"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.dax.create_subnet_group
hub.exec.boto3.client.dax.delete_subnet_group
hub.exec.boto3.client.dax.describe_subnet_groups
hub.exec.boto3.client.dax.update_subnet_group
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, subnet_group_name: Text, subnet_ids: List, description: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new subnet group.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        subnet_group_name(Text): A name for the subnet group. This value is stored as a lowercase string.
        description(Text, optional): A description for the subnet group. Defaults to None.
        subnet_ids(List): A list of VPC subnet IDs for the subnet group.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.dax.subnet_group.present:
                - name: value
                - subnet_group_name: value
                - subnet_ids: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.dax.subnet_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.dax.describe_subnet_groups(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.dax.create_subnet_group(
                ctx,
                
                
                **{"SubnetGroupName": subnet_group_name, "Description": description, "SubnetIds": subnet_ids}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.dax.describe_subnet_groups(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, subnet_group_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a subnet group.  You cannot delete a subnet group if it is associated with any DAX clusters.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        subnet_group_name(Text): The name of the subnet group to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.dax.subnet_group.absent:
                - name: value
                - subnet_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.dax.subnet_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.dax.describe_subnet_groups(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.dax.delete_subnet_group(
                ctx,
                
                
                **{"SubnetGroupName": subnet_group_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.dax.describe_subnet_groups(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

