"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.devicefarm.create_project
hub.exec.boto3.client.devicefarm.delete_project
hub.exec.boto3.client.devicefarm.get_project
hub.exec.boto3.client.devicefarm.list_projects
hub.exec.boto3.client.devicefarm.update_project
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, default_job_timeout_minutes: int = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a project.

    Args:
        name(Text): The project's name.
        default_job_timeout_minutes(int, optional): Sets the execution timeout value (in minutes) for a project. All test runs in this project use
            the specified execution timeout value unless overridden when scheduling a run. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.devicefarm.project.present:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.devicefarm.project.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.devicefarm.get_project(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.devicefarm.create_project(
                ctx,
                
                
                **{"Name": name, "defaultJobTimeoutMinutes": default_job_timeout_minutes}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.devicefarm.get_project(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an AWS Device Farm project, given the project ARN.  Deleting this resource does not stop an in-progress
    run.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        arn(Text): Represents the Amazon Resource Name (ARN) of the Device Farm project to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.devicefarm.project.absent:
                - name: value
                - arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.devicefarm.project.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.devicefarm.get_project(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.devicefarm.delete_project(
                ctx,
                
                
                **{"arn": arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.devicefarm.get_project(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

