"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.devicefarm.create_test_grid_project
hub.exec.boto3.client.devicefarm.delete_test_grid_project
hub.exec.boto3.client.devicefarm.get_test_grid_project
hub.exec.boto3.client.devicefarm.list_test_grid_projects
hub.exec.boto3.client.devicefarm.update_test_grid_project
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, description: Text = None, vpc_config: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a Selenium testing project. Projects are used to track TestGridSession instances.

    Args:
        name(Text): Human-readable name of the Selenium testing project.
        description(Text, optional): Human-readable description of the project. Defaults to None.
        vpc_config(Dict, optional): The VPC security groups and subnets that are attached to a project. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.devicefarm.test_grid_project.present:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.devicefarm.test_grid_project.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.devicefarm.get_test_grid_project(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.devicefarm.create_test_grid_project(
                ctx,
                
                
                **{"Name": name, "description": description, "vpcConfig": vpc_config}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.devicefarm.get_test_grid_project(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, project_arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
     Deletes a Selenium testing project and all content generated under it.   You cannot undo this operation.   You
    cannot delete a project if it has active sessions.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        project_arn(Text): The ARN of the project to delete, from CreateTestGridProject or ListTestGridProjects.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.devicefarm.test_grid_project.absent:
                - name: value
                - project_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.devicefarm.test_grid_project.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.devicefarm.get_test_grid_project(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.devicefarm.delete_test_grid_project(
                ctx,
                
                
                **{"projectArn": project_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.devicefarm.get_test_grid_project(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

