"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ds.create_log_subscription
hub.exec.boto3.client.ds.delete_log_subscription
hub.exec.boto3.client.ds.list_log_subscriptions
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, directory_id: Text, log_group_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a subscription to forward real-time Directory Service domain controller security logs to the specified
    Amazon CloudWatch log group in your Amazon Web Services account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        directory_id(Text): Identifier of the directory to which you want to subscribe and receive real-time logs to your
            specified CloudWatch log group.
        log_group_name(Text): The name of the CloudWatch log group where the real-time domain controller logs are forwarded.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ds.log_subscription.present:
                - name: value
                - directory_id: value
                - log_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ds.log_subscription.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ds.list_log_subscriptions(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ds.create_log_subscription(
                ctx,
                
                
                **{"DirectoryId": directory_id, "LogGroupName": log_group_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ds.list_log_subscriptions(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, directory_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the specified log subscription.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        directory_id(Text): Identifier of the directory whose log subscription you want to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ds.log_subscription.absent:
                - name: value
                - directory_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ds.log_subscription.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ds.list_log_subscriptions(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ds.delete_log_subscription(
                ctx,
                
                
                **{"DirectoryId": directory_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ds.list_log_subscriptions(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

