"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ds.accept_shared_directory
hub.exec.boto3.client.ds.describe_shared_directories
hub.exec.boto3.client.ds.reject_shared_directory
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, shared_directory_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Accepts a directory sharing request that was sent from the directory owner account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        shared_directory_id(Text): Identifier of the shared directory in the directory consumer account. This identifier is
            different for each directory owner account.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ds.shared_directory.present:
                - name: value
                - shared_directory_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ds.shared_directory.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ds.describe_shared_directories(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ds.accept_shared_directory(
                ctx,
                
                
                **{"SharedDirectoryId": shared_directory_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ds.describe_shared_directories(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, shared_directory_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Rejects a directory sharing request that was sent from the directory owner account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        shared_directory_id(Text): Identifier of the shared directory in the directory consumer account. This identifier is
            different for each directory owner account.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ds.shared_directory.absent:
                - name: value
                - shared_directory_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ds.shared_directory.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ds.describe_shared_directories(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ds.reject_shared_directory(
                ctx,
                
                
                **{"SharedDirectoryId": shared_directory_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ds.describe_shared_directories(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

