"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.dynamodb.describe_kinesis_streaming_destination
hub.exec.boto3.client.dynamodb.disable_kinesis_streaming_destination
hub.exec.boto3.client.dynamodb.enable_kinesis_streaming_destination
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, table_name: Text, stream_arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Starts table data replication to the specified Kinesis data stream at a timestamp chosen during the enable
    workflow. If this operation doesn't return results immediately, use DescribeKinesisStreamingDestination to check
    if streaming to the Kinesis data stream is ACTIVE.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        table_name(Text): The name of the DynamoDB table.
        stream_arn(Text): The ARN for a Kinesis data stream.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.dynamodb.kinesis_streaming_destination.present:
                - name: value
                - table_name: value
                - stream_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.dynamodb.kinesis_streaming_destination.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.dynamodb.describe_kinesis_streaming_destination(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.dynamodb.enable_kinesis_streaming_destination(
                ctx,
                
                
                **{"TableName": table_name, "StreamArn": stream_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.dynamodb.describe_kinesis_streaming_destination(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, table_name: Text, stream_arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Stops replication from the DynamoDB table to the Kinesis data stream. This is done without deleting either of
    the resources.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        table_name(Text): The name of the DynamoDB table.
        stream_arn(Text): The ARN for a Kinesis data stream.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.dynamodb.kinesis_streaming_destination.absent:
                - name: value
                - table_name: value
                - stream_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.dynamodb.kinesis_streaming_destination.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.dynamodb.describe_kinesis_streaming_destination(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.dynamodb.disable_kinesis_streaming_destination(
                ctx,
                
                
                **{"TableName": table_name, "StreamArn": stream_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.dynamodb.describe_kinesis_streaming_destination(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

