"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ec2.deregister_instance_event_notification_attributes
hub.exec.boto3.client.ec2.describe_instance_event_notification_attributes
hub.exec.boto3.client.ec2.register_instance_event_notification_attributes
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, instance_tag_attribute: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Registers a set of tag keys to include in scheduled event notifications for your resources.  To remove tags, use
    .

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        instance_tag_attribute(Dict, optional): Information about the tag keys to register. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ec2.instance_event_notification_attribute.present:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ec2.instance_event_notification_attribute.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ec2.describe_instance_event_notification_attributes(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ec2.register_instance_event_notification_attributes(
                ctx,
                DryRun=ctx.test,
                
                **{"InstanceTagAttribute": instance_tag_attribute}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ec2.describe_instance_event_notification_attributes(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, instance_tag_attribute: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    c Deregisters tag keys to prevent tags that have the specified tag keys from being included in scheduled event
    notifications for resources in the Region.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        instance_tag_attribute(Dict, optional): Information about the tag keys to deregister. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ec2.instance_event_notification_attribute.absent:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ec2.instance_event_notification_attribute.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ec2.describe_instance_event_notification_attributes(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ec2.deregister_instance_event_notification_attributes(
                ctx,
                DryRun=ctx.test,
                
                **{"InstanceTagAttribute": instance_tag_attribute}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ec2.describe_instance_event_notification_attributes(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

