"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ec2.create_transit_gateway_connect
hub.exec.boto3.client.ec2.delete_transit_gateway_connect
hub.exec.boto3.client.ec2.describe_transit_gateway_connects
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, transport_transit_gateway_attachment_id: Text, options: Dict, tag_specifications: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a Connect attachment from a specified transit gateway attachment. A Connect attachment is a GRE-based
    tunnel attachment that you can use to establish a connection between a transit gateway and an appliance. A
    Connect attachment uses an existing VPC or AWS Direct Connect attachment as the underlying transport mechanism.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        transport_transit_gateway_attachment_id(Text): The ID of the transit gateway attachment. You can specify a VPC attachment or a AWS Direct
            Connect attachment.
        options(Dict): The Connect attachment options.
        tag_specifications(List, optional): The tags to apply to the Connect attachment. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ec2.transit_gateway_connect.present:
                - name: value
                - transport_transit_gateway_attachment_id: value
                - options: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ec2.transit_gateway_connect.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ec2.describe_transit_gateway_connects(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ec2.create_transit_gateway_connect(
                ctx,
                DryRun=ctx.test,
                
                **{"TransportTransitGatewayAttachmentId": transport_transit_gateway_attachment_id, "Options": options, "TagSpecifications": tag_specifications}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ec2.describe_transit_gateway_connects(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, transit_gateway_attachment_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the specified Connect attachment. You must first delete any Connect peers for the attachment.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        transit_gateway_attachment_id(Text): The ID of the Connect attachment.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ec2.transit_gateway_connect.absent:
                - name: value
                - transit_gateway_attachment_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ec2.transit_gateway_connect.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ec2.describe_transit_gateway_connects(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ec2.delete_transit_gateway_connect(
                ctx,
                DryRun=ctx.test,
                
                **{"TransitGatewayAttachmentId": transit_gateway_attachment_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ec2.describe_transit_gateway_connects(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

