"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ec2.disable_transit_gateway_route_table_propagation
hub.exec.boto3.client.ec2.enable_transit_gateway_route_table_propagation
hub.exec.boto3.client.ec2.get_transit_gateway_route_table_propagations
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, transit_gateway_route_table_id: Text, transit_gateway_attachment_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Enables the specified attachment to propagate routes to the specified propagation route table.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        transit_gateway_route_table_id(Text): The ID of the propagation route table.
        transit_gateway_attachment_id(Text): The ID of the attachment.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ec2.transit_gateway_route_table_propagation.present:
                - name: value
                - transit_gateway_route_table_id: value
                - transit_gateway_attachment_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ec2.transit_gateway_route_table_propagation.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ec2.get_transit_gateway_route_table_propagations(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ec2.enable_transit_gateway_route_table_propagation(
                ctx,
                DryRun=ctx.test,
                
                **{"TransitGatewayRouteTableId": transit_gateway_route_table_id, "TransitGatewayAttachmentId": transit_gateway_attachment_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ec2.get_transit_gateway_route_table_propagations(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, transit_gateway_route_table_id: Text, transit_gateway_attachment_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Disables the specified resource attachment from propagating routes to the specified propagation route table.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        transit_gateway_route_table_id(Text): The ID of the propagation route table.
        transit_gateway_attachment_id(Text): The ID of the attachment.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ec2.transit_gateway_route_table_propagation.absent:
                - name: value
                - transit_gateway_route_table_id: value
                - transit_gateway_attachment_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ec2.transit_gateway_route_table_propagation.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ec2.get_transit_gateway_route_table_propagations(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ec2.disable_transit_gateway_route_table_propagation(
                ctx,
                DryRun=ctx.test,
                
                **{"TransitGatewayRouteTableId": transit_gateway_route_table_id, "TransitGatewayAttachmentId": transit_gateway_attachment_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ec2.get_transit_gateway_route_table_propagations(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

