"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ec2.attach_volume
hub.exec.boto3.client.ec2.create_volume
hub.exec.boto3.client.ec2.delete_volume
hub.exec.boto3.client.ec2.describe_volumes
hub.exec.boto3.client.ec2.detach_volume
hub.exec.boto3.client.ec2.import_volume
hub.exec.boto3.client.ec2.modify_volume
resource = hub.tool.boto3.resource.create(ctx, "ec2", "Volume", name)
hub.tool.boto3.resource.exec(resource, attach_to_instance, *args, **kwargs)
hub.tool.boto3.resource.exec(resource, create_snapshot, *args, **kwargs)
hub.tool.boto3.resource.exec(resource, create_tags, *args, **kwargs)
hub.tool.boto3.resource.exec(resource, delete, *args, **kwargs)
hub.tool.boto3.resource.exec(resource, describe_attribute, *args, **kwargs)
hub.tool.boto3.resource.exec(resource, describe_status, *args, **kwargs)
hub.tool.boto3.resource.exec(resource, detach_from_instance, *args, **kwargs)
hub.tool.boto3.resource.exec(resource, enable_io, *args, **kwargs)
hub.tool.boto3.resource.exec(resource, modify_attribute, *args, **kwargs)
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, availability_zone: Text, encrypted: bool = None, iops: int = None, kms_key_id: Text = None, outpost_arn: Text = None, size: int = None, snapshot_id: Text = None, volume_type: Text = None, tag_specifications: List = None, multi_attach_enabled: bool = None, throughput: int = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an EBS volume that can be attached to an instance in the same Availability Zone. You can create a new
    empty volume or restore a volume from an EBS snapshot. Any Amazon Web Services Marketplace product codes from
    the snapshot are propagated to the volume. You can create encrypted volumes. Encrypted volumes must be attached
    to instances that support Amazon EBS encryption. Volumes that are created from encrypted snapshots are also
    automatically encrypted. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud
    User Guide. You can tag your volumes during creation. For more information, see Tag your Amazon EC2 resources in
    the Amazon Elastic Compute Cloud User Guide. For more information, see Create an Amazon EBS volume in the Amazon
    Elastic Compute Cloud User Guide.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        availability_zone(Text): The Availability Zone in which to create the volume.
        encrypted(bool, optional): Indicates whether the volume should be encrypted. The effect of setting the encryption state to
            true depends on the volume origin (new or from a snapshot), starting encryption state,
            ownership, and whether encryption by default is enabled. For more information, see Encryption by
            default in the Amazon Elastic Compute Cloud User Guide. Encrypted Amazon EBS volumes must be
            attached to instances that support Amazon EBS encryption. For more information, see Supported
            instance types. Defaults to None.
        iops(int, optional): The number of I/O operations per second (IOPS). For gp3, io1, and io2 volumes, this represents
            the number of IOPS that are provisioned for the volume. For gp2 volumes, this represents the
            baseline performance of the volume and the rate at which the volume accumulates I/O credits for
            bursting. The following are the supported values for each volume type:    gp3: 3,000-16,000 IOPS
            io1: 100-64,000 IOPS    io2: 100-64,000 IOPS    io1 and io2 volumes support up to 64,000 IOPS
            only on Instances built on the Nitro System. Other instance families support performance up to
            32,000 IOPS. This parameter is required for io1 and io2 volumes. The default for gp3 volumes is
            3,000 IOPS. This parameter is not supported for gp2, st1, sc1, or standard volumes. Defaults to None.
        kms_key_id(Text, optional): The identifier of the Key Management Service (KMS) KMS key to use for Amazon EBS encryption. If
            this parameter is not specified, your KMS key for Amazon EBS is used. If KmsKeyId is specified,
            the encrypted state must be true. You can specify the KMS key using any of the following:   Key
            ID. For example, 1234abcd-12ab-34cd-56ef-1234567890ab.   Key alias. For example,
            alias/ExampleAlias.   Key ARN. For example, arn:aws:kms:us-
            east-1:012345678910:key/1234abcd-12ab-34cd-56ef-1234567890ab.   Alias ARN. For example,
            arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.   Amazon Web Services authenticates the
            KMS key asynchronously. Therefore, if you specify an ID, alias, or ARN that is not valid, the
            action can appear to complete, but eventually fails. Defaults to None.
        outpost_arn(Text, optional): The Amazon Resource Name (ARN) of the Outpost. Defaults to None.
        size(int, optional): The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. If you
            specify a snapshot, the default is the snapshot size. You can specify a volume size that is
            equal to or larger than the snapshot size. The following are the supported volumes sizes for
            each volume type:    gp2 and gp3: 1-16,384    io1 and io2: 4-16,384    st1 and sc1: 125-16,384
            standard: 1-1,024. Defaults to None.
        snapshot_id(Text, optional): The snapshot from which to create the volume. You must specify either a snapshot ID or a volume
            size. Defaults to None.
        volume_type(Text, optional): The volume type. This parameter can be one of the following values:   General Purpose SSD: gp2 |
            gp3    Provisioned IOPS SSD: io1 | io2    Throughput Optimized HDD: st1    Cold HDD: sc1
            Magnetic: standard    For more information, see Amazon EBS volume types in the Amazon Elastic
            Compute Cloud User Guide. Default: gp2. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the volume during creation. Defaults to None.
        multi_attach_enabled(bool, optional): Indicates whether to enable Amazon EBS Multi-Attach. If you enable Multi-Attach, you can attach
            the volume to up to 16 Instances built on the Nitro System in the same Availability Zone. This
            parameter is supported with io1 and io2 volumes only. For more information, see  Amazon EBS
            Multi-Attach in the Amazon Elastic Compute Cloud User Guide. Defaults to None.
        throughput(int, optional): The throughput to provision for a volume, with a maximum of 1,000 MiB/s. This parameter is valid
            only for gp3 volumes. Valid Range: Minimum value of 125. Maximum value of 1000. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ec2.volume.present:
                - name: value
                - availability_zone: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ec2.volume.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    resource = hub.tool.boto3.resource.create(ctx, "ec2", "Volume", name)
    before = await hub.tool.boto3.resource.describe(resource)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ec2.create_volume(
                ctx,
                DryRun=ctx.test,
                ClientToken=name,
                **{"AvailabilityZone": availability_zone, "Encrypted": encrypted, "Iops": iops, "KmsKeyId": kms_key_id, "OutpostArn": outpost_arn, "Size": size, "SnapshotId": snapshot_id, "VolumeType": volume_type, "TagSpecifications": tag_specifications, "MultiAttachEnabled": multi_attach_enabled, "Throughput": throughput}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.tool.boto3.resource.describe(resource)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, volume_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the specified EBS volume. The volume must be in the available state (not attached to an instance). The
    volume can remain in the deleting state for several minutes. For more information, see Delete an Amazon EBS
    volume in the Amazon Elastic Compute Cloud User Guide.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        volume_id(Text): The ID of the volume.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ec2.volume.absent:
                - name: value
                - volume_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ec2.volume.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    resource = hub.tool.boto3.resource.create(ctx, "ec2", "Volume", name)

    before = await hub.tool.boto3.resource.describe(resource)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ec2.delete_volume(
                ctx,
                DryRun=ctx.test,
                
                **{"VolumeId": volume_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.tool.boto3.resource.describe(resource)
    result["changes"] = differ.deep_diff(before, after)
    return result

