"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ecr.delete_lifecycle_policy
hub.exec.boto3.client.ecr.get_lifecycle_policy
hub.exec.boto3.client.ecr.put_lifecycle_policy
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, repository_name: Text, lifecycle_policy_text: Text, registry_id: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates or updates the lifecycle policy for the specified repository. For more information, see Lifecycle Policy
    Template.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        registry_id(Text, optional): The AWS account ID associated with the registry that contains the repository. If you do  not
            specify a registry, the default registry is assumed. Defaults to None.
        repository_name(Text): The name of the repository to receive the policy.
        lifecycle_policy_text(Text): The JSON repository policy text to apply to the repository.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ecr.lifecycle_policy.present:
                - name: value
                - repository_name: value
                - lifecycle_policy_text: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ecr.lifecycle_policy.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ecr.get_lifecycle_policy(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ecr.put_lifecycle_policy(
                ctx,
                
                
                **{"registryId": registry_id, "repositoryName": repository_name, "lifecyclePolicyText": lifecycle_policy_text}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ecr.get_lifecycle_policy(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, repository_name: Text, registry_id: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the lifecycle policy associated with the specified repository.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        registry_id(Text, optional): The AWS account ID associated with the registry that contains the repository. If you do not
            specify a registry, the default registry is assumed. Defaults to None.
        repository_name(Text): The name of the repository.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ecr.lifecycle_policy.absent:
                - name: value
                - repository_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ecr.lifecycle_policy.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ecr.get_lifecycle_policy(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ecr.delete_lifecycle_policy(
                ctx,
                
                
                **{"registryId": registry_id, "repositoryName": repository_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ecr.get_lifecycle_policy(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

