"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.elasticache.create_cache_security_group
hub.exec.boto3.client.elasticache.delete_cache_security_group
hub.exec.boto3.client.elasticache.describe_cache_security_groups
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, cache_security_group_name: Text, description: Text, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new cache security group. Use a cache security group to control access to one or more clusters. Cache
    security groups are only used when you are creating a cluster outside of an Amazon Virtual Private Cloud (Amazon
    VPC). If you are creating a cluster inside of a VPC, use a cache subnet group instead. For more information, see
    CreateCacheSubnetGroup.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        cache_security_group_name(Text): A name for the cache security group. This value is stored as a lowercase string. Constraints:
            Must contain no more than 255 alphanumeric characters. Cannot be the word "Default". Example:
            mysecuritygroup.
        description(Text): A description for the cache security group.
        tags(List, optional): A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be
            accompanied by a tag value, although null is accepted. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.elasticache.cache_security_group.present:
                - name: value
                - cache_security_group_name: value
                - description: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.elasticache.cache_security_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.elasticache.describe_cache_security_groups(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.elasticache.create_cache_security_group(
                ctx,
                
                
                **{"CacheSecurityGroupName": cache_security_group_name, "Description": description, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.elasticache.describe_cache_security_groups(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, cache_security_group_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a cache security group.  You cannot delete a cache security group if it is associated with any clusters.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        cache_security_group_name(Text): The name of the cache security group to delete.  You cannot delete the default security group.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.elasticache.cache_security_group.absent:
                - name: value
                - cache_security_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.elasticache.cache_security_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.elasticache.describe_cache_security_groups(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.elasticache.delete_cache_security_group(
                ctx,
                
                
                **{"CacheSecurityGroupName": cache_security_group_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.elasticache.describe_cache_security_groups(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

