"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.elasticache.create_user_group
hub.exec.boto3.client.elasticache.delete_user_group
hub.exec.boto3.client.elasticache.describe_user_groups
hub.exec.boto3.client.elasticache.modify_user_group
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, user_group_id: Text, engine: Text, user_ids: List = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    For Redis engine version 6.x onwards: Creates a Redis user group. For more information, see Using Role Based
    Access Control (RBAC)

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        user_group_id(Text): The ID of the user group.
        engine(Text): The current supported value is Redis.
        user_ids(List, optional): The list of user IDs that belong to the user group. Defaults to None.
        tags(List, optional): A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be
            accompanied by a tag value, although null is accepted. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.elasticache.user_group.present:
                - name: value
                - user_group_id: value
                - engine: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.elasticache.user_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.elasticache.describe_user_groups(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.elasticache.create_user_group(
                ctx,
                
                
                **{"UserGroupId": user_group_id, "Engine": engine, "UserIds": user_ids, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.elasticache.describe_user_groups(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, user_group_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    For Redis engine version 6.x onwards: Deletes a user group. The user group must first be disassociated from the
    replication group before it can be deleted. For more information, see Using Role Based Access Control (RBAC).

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        user_group_id(Text): The ID of the user group.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.elasticache.user_group.absent:
                - name: value
                - user_group_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.elasticache.user_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.elasticache.describe_user_groups(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.elasticache.delete_user_group(
                ctx,
                
                
                **{"UserGroupId": user_group_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.elasticache.describe_user_groups(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

