"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.emr.create_security_configuration
hub.exec.boto3.client.emr.delete_security_configuration
hub.exec.boto3.client.emr.describe_security_configuration
hub.exec.boto3.client.emr.list_security_configurations
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, security_configuration: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a security configuration, which is stored in the service and can be specified when a cluster is created.

    Args:
        name(Text): The name of the security configuration.
        security_configuration(Text): The security configuration details in JSON format. For JSON parameters and examples, see Use
            Security Configurations to Set Up Cluster Security in the Amazon EMR Management Guide.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.emr.security_configuration.present:
                - name: value
                - security_configuration: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.emr.security_configuration.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.emr.describe_security_configuration(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.emr.create_security_configuration(
                ctx,
                
                
                **{"Name": name, "SecurityConfiguration": security_configuration}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.emr.describe_security_configuration(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a security configuration.

    Args:
        name(Text): The name of the security configuration.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.emr.security_configuration.absent:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.emr.security_configuration.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.emr.describe_security_configuration(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.emr.delete_security_configuration(
                ctx,
                
                
                **{"Name": name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.emr.describe_security_configuration(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

