"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.events.create_connection
hub.exec.boto3.client.events.deauthorize_connection
hub.exec.boto3.client.events.delete_connection
hub.exec.boto3.client.events.describe_connection
hub.exec.boto3.client.events.list_connections
hub.exec.boto3.client.events.update_connection
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, authorization_type: Text, auth_parameters: Dict, description: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a connection. A connection defines the authorization type and credentials to use for authorization with
    an API destination HTTP endpoint.

    Args:
        name(Text): The name for the connection to create.
        description(Text, optional): A description for the connection to create. Defaults to None.
        authorization_type(Text): The type of authorization to use for the connection.
        auth_parameters(Dict): A CreateConnectionAuthRequestParameters object that contains the authorization parameters to use
            to authorize with the endpoint.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.events.connection.present:
                - name: value
                - authorization_type: value
                - auth_parameters: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.events.connection.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.events.describe_connection(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.events.create_connection(
                ctx,
                
                
                **{"Name": name, "Description": description, "AuthorizationType": authorization_type, "AuthParameters": auth_parameters}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.events.describe_connection(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a connection.

    Args:
        name(Text): The name of the connection to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.events.connection.absent:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.events.connection.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.events.describe_connection(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.events.delete_connection(
                ctx,
                
                
                **{"Name": name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.events.describe_connection(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

