"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.fms.delete_apps_list
hub.exec.boto3.client.fms.get_apps_list
hub.exec.boto3.client.fms.list_apps_lists
hub.exec.boto3.client.fms.put_apps_list
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, apps_list: Dict, tag_list: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an Firewall Manager applications list.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        apps_list(Dict): The details of the Firewall Manager applications list to be created.
        tag_list(List, optional): The tags associated with the resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.fms.apps_list.present:
                - name: value
                - apps_list: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.fms.apps_list.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.fms.get_apps_list(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.fms.put_apps_list(
                ctx,
                
                
                **{"AppsList": apps_list, "TagList": tag_list}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.fms.get_apps_list(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, list_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Permanently deletes an Firewall Manager applications list.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        list_id(Text): The ID of the applications list that you want to delete. You can retrieve this ID from
            PutAppsList, ListAppsLists, and GetAppsList.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.fms.apps_list.absent:
                - name: value
                - list_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.fms.apps_list.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.fms.get_apps_list(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.fms.delete_apps_list(
                ctx,
                
                
                **{"ListId": list_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.fms.get_apps_list(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

