"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.fms.delete_protocols_list
hub.exec.boto3.client.fms.get_protocols_list
hub.exec.boto3.client.fms.list_protocols_lists
hub.exec.boto3.client.fms.put_protocols_list
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, protocols_list: Dict, tag_list: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an Firewall Manager protocols list.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        protocols_list(Dict): The details of the Firewall Manager protocols list to be created.
        tag_list(List, optional): The tags associated with the resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.fms.protocols_list.present:
                - name: value
                - protocols_list: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.fms.protocols_list.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.fms.get_protocols_list(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.fms.put_protocols_list(
                ctx,
                
                
                **{"ProtocolsList": protocols_list, "TagList": tag_list}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.fms.get_protocols_list(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, list_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Permanently deletes an Firewall Manager protocols list.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        list_id(Text): The ID of the protocols list that you want to delete. You can retrieve this ID from
            PutProtocolsList, ListProtocolsLists, and GetProtocolsLost.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.fms.protocols_list.absent:
                - name: value
                - list_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.fms.protocols_list.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.fms.get_protocols_list(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.fms.delete_protocols_list(
                ctx,
                
                
                **{"ListId": list_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.fms.get_protocols_list(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

