"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.frauddetector.create_model
hub.exec.boto3.client.frauddetector.delete_model
hub.exec.boto3.client.frauddetector.get_models
hub.exec.boto3.client.frauddetector.update_model
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, model_id: Text, model_type: Text, event_type_name: Text, description: Text = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a model using the specified model type.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        model_id(Text): The model ID.
        model_type(Text): The model type.
        description(Text, optional): The model description. Defaults to None.
        event_type_name(Text): The name of the event type.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.frauddetector.model.present:
                - name: value
                - model_id: value
                - model_type: value
                - event_type_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.frauddetector.model.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.frauddetector.get_models(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.frauddetector.create_model(
                ctx,
                
                
                **{"modelId": model_id, "modelType": model_type, "description": description, "eventTypeName": event_type_name, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.frauddetector.get_models(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, model_id: Text, model_type: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a model. You can delete models and model versions in Amazon Fraud Detector, provided that they are not
    associated with a detector version.  When you delete a model, Amazon Fraud Detector permanently deletes that
    model and the data is no longer stored in Amazon Fraud Detector.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        model_id(Text): The model ID of the model to delete.
        model_type(Text): The model type of the model to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.frauddetector.model.absent:
                - name: value
                - model_id: value
                - model_type: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.frauddetector.model.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.frauddetector.get_models(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.frauddetector.delete_model(
                ctx,
                
                
                **{"modelId": model_id, "modelType": model_type}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.frauddetector.get_models(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

