"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.globalaccelerator.create_custom_routing_listener
hub.exec.boto3.client.globalaccelerator.delete_custom_routing_listener
hub.exec.boto3.client.globalaccelerator.describe_custom_routing_listener
hub.exec.boto3.client.globalaccelerator.list_custom_routing_listeners
hub.exec.boto3.client.globalaccelerator.update_custom_routing_listener
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, accelerator_arn: Text, port_ranges: List, idempotency_token: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Create a listener to process inbound connections from clients to a custom routing accelerator. Connections
    arrive to assigned static IP addresses on the port range that you specify.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        accelerator_arn(Text): The Amazon Resource Name (ARN) of the accelerator for a custom routing listener.
        port_ranges(List): The port range to support for connections from clients to your accelerator. Separately, you set
            port ranges for endpoints. For more information, see About endpoints for custom routing
            accelerators.
        idempotency_token(Text): A unique, case-sensitive identifier that you provide to ensure the idempotency—that is, the
            uniqueness—of the request.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.globalaccelerator.custom_routing_listener.present:
                - name: value
                - accelerator_arn: value
                - port_ranges: value
                - idempotency_token: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.globalaccelerator.custom_routing_listener.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.globalaccelerator.describe_custom_routing_listener(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.globalaccelerator.create_custom_routing_listener(
                ctx,
                
                
                **{"AcceleratorArn": accelerator_arn, "PortRanges": port_ranges, "IdempotencyToken": idempotency_token}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.globalaccelerator.describe_custom_routing_listener(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, listener_arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Delete a listener for a custom routing accelerator.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        listener_arn(Text): The Amazon Resource Name (ARN) of the listener to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.globalaccelerator.custom_routing_listener.absent:
                - name: value
                - listener_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.globalaccelerator.custom_routing_listener.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.globalaccelerator.describe_custom_routing_listener(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.globalaccelerator.delete_custom_routing_listener(
                ctx,
                
                
                **{"ListenerArn": listener_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.globalaccelerator.describe_custom_routing_listener(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

