"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.glue.create_classifier
hub.exec.boto3.client.glue.delete_classifier
hub.exec.boto3.client.glue.get_classifiers
hub.exec.boto3.client.glue.update_classifier
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, grok_classifier: Dict = None, xml_classifier: Dict = None, json_classifier: Dict = None, csv_classifier: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a classifier in the user's account. This can be a GrokClassifier, an XMLClassifier, a JsonClassifier, or
    a CsvClassifier, depending on which field of the request is present.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        grok_classifier(Dict, optional): A GrokClassifier object specifying the classifier to create. Defaults to None.
        xml_classifier(Dict, optional): An XMLClassifier object specifying the classifier to create. Defaults to None.
        json_classifier(Dict, optional): A JsonClassifier object specifying the classifier to create. Defaults to None.
        csv_classifier(Dict, optional): A CsvClassifier object specifying the classifier to create. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.glue.classifier.present:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.glue.classifier.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.glue.get_classifiers(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.glue.create_classifier(
                ctx,
                
                
                **{"GrokClassifier": grok_classifier, "XMLClassifier": xml_classifier, "JsonClassifier": json_classifier, "CsvClassifier": csv_classifier}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.glue.get_classifiers(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Removes a classifier from the Data Catalog.

    Args:
        name(Text): Name of the classifier to remove.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.glue.classifier.absent:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.glue.classifier.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.glue.get_classifiers(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.glue.delete_classifier(
                ctx,
                
                
                **{"Name": name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.glue.get_classifiers(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

