"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.greengrass.create_function_definition
hub.exec.boto3.client.greengrass.delete_function_definition
hub.exec.boto3.client.greengrass.get_function_definition
hub.exec.boto3.client.greengrass.list_function_definitions
hub.exec.boto3.client.greengrass.update_function_definition
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text = None, amzn_client_token: Text = None, initial_version: Dict = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a Lambda function definition which contains a list of Lambda functions and their configurations to be
    used in a group. You can create an initial version of the definition by providing a list of Lambda functions and
    their configurations now, or use ''CreateFunctionDefinitionVersion'' later.

    Args:
        name(Text, optional): The name of the function definition. Defaults to None.
        amzn_client_token(Text, optional): A client token used to correlate requests and responses. Defaults to None.
        initial_version(Dict, optional): Information about the initial version of the function definition. Defaults to None.
        tags(Dict, optional): Tag(s) to add to the new resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.greengrass.function_definition.present:
                - 
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.greengrass.function_definition.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.greengrass.get_function_definition(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.greengrass.create_function_definition(
                ctx,
                
                
                **{"Name": name, "AmznClientToken": amzn_client_token, "InitialVersion": initial_version, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.greengrass.get_function_definition(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, function_definition_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a Lambda function definition.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        function_definition_id(Text): The ID of the Lambda function definition.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.greengrass.function_definition.absent:
                - name: value
                - function_definition_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.greengrass.function_definition.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.greengrass.get_function_definition(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.greengrass.delete_function_definition(
                ctx,
                
                
                **{"FunctionDefinitionId": function_definition_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.greengrass.get_function_definition(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

