"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.greengrass.create_group
hub.exec.boto3.client.greengrass.delete_group
hub.exec.boto3.client.greengrass.get_group
hub.exec.boto3.client.greengrass.list_groups
hub.exec.boto3.client.greengrass.update_group
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, amzn_client_token: Text = None, initial_version: Dict = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a group. You may provide the initial version of the group or use ''CreateGroupVersion'' at a later time.
    Tip: You can use the ''gg_group_setup'' package (https://github.com/awslabs/aws-greengrass-group-setup) as a
    library or command-line application to create and deploy Greengrass groups.

    Args:
        name(Text): The name of the group.
        amzn_client_token(Text, optional): A client token used to correlate requests and responses. Defaults to None.
        initial_version(Dict, optional): Information about the initial version of the group. Defaults to None.
        tags(Dict, optional): Tag(s) to add to the new resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.greengrass.group.present:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.greengrass.group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.greengrass.get_group(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.greengrass.create_group(
                ctx,
                
                
                **{"Name": name, "AmznClientToken": amzn_client_token, "InitialVersion": initial_version, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.greengrass.get_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, group_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a group.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        group_id(Text): The ID of the Greengrass group.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.greengrass.group.absent:
                - name: value
                - group_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.greengrass.group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.greengrass.get_group(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.greengrass.delete_group(
                ctx,
                
                
                **{"GroupId": group_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.greengrass.get_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

