"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.groundstation.create_config
hub.exec.boto3.client.groundstation.delete_config
hub.exec.boto3.client.groundstation.get_config
hub.exec.boto3.client.groundstation.list_configs
hub.exec.boto3.client.groundstation.update_config
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, config_data: Dict, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a Config with the specified configData parameters. Only one type of configData can be specified.

    Args:
        name(Text): Name of a Config.
        config_data(Dict): Parameters of a Config.
        tags(Dict, optional): Tags assigned to a Config. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.groundstation.config.present:
                - name: value
                - config_data: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.groundstation.config.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.groundstation.get_config(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.groundstation.create_config(
                ctx,
                
                
                **{"Name": name, "configData": config_data, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.groundstation.get_config(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, config_id: Text, config_type: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a Config.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        config_id(Text): UUID of a Config.
        config_type(Text): Type of a Config.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.groundstation.config.absent:
                - name: value
                - config_id: value
                - config_type: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.groundstation.config.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.groundstation.get_config(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.groundstation.delete_config(
                ctx,
                
                
                **{"configId": config_id, "configType": config_type}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.groundstation.get_config(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

