"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.guardduty.accept_invitation
hub.exec.boto3.client.guardduty.decline_invitations
hub.exec.boto3.client.guardduty.delete_invitations
hub.exec.boto3.client.guardduty.list_invitations
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, detector_id: Text, master_id: Text, invitation_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Accepts the invitation to be monitored by a GuardDuty administrator account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        detector_id(Text): The unique ID of the detector of the GuardDuty member account.
        master_id(Text): The account ID of the GuardDuty administrator account whose invitation you're accepting.
        invitation_id(Text): The value that is used to validate the administrator account to the member account.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.guardduty.invitation.present:
                - name: value
                - detector_id: value
                - master_id: value
                - invitation_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.guardduty.invitation.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.guardduty.list_invitations(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.guardduty.accept_invitation(
                ctx,
                
                
                **{"DetectorId": detector_id, "MasterId": master_id, "InvitationId": invitation_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.guardduty.list_invitations(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, account_ids: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes invitations sent to the current member account by AWS accounts specified by their account IDs.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        account_ids(List): A list of account IDs of the AWS accounts that sent invitations to the current member account
            that you want to delete invitations from.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.guardduty.invitation.absent:
                - name: value
                - account_ids: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.guardduty.invitation.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.guardduty.list_invitations(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.guardduty.delete_invitations(
                ctx,
                
                
                **{"AccountIds": account_ids}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.guardduty.list_invitations(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

