"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iot.create_provisioning_template_version
hub.exec.boto3.client.iot.delete_provisioning_template_version
hub.exec.boto3.client.iot.describe_provisioning_template_version
hub.exec.boto3.client.iot.list_provisioning_template_versions
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, template_name: Text, template_body: Text, set_as_default: bool = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new version of a fleet provisioning template.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        template_name(Text): The name of the fleet provisioning template.
        template_body(Text): The JSON formatted contents of the fleet provisioning template.
        set_as_default(bool, optional): Sets a fleet provision template version as the default version. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iot.provisioning_template_version.present:
                - name: value
                - template_name: value
                - template_body: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iot.provisioning_template_version.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iot.describe_provisioning_template_version(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iot.create_provisioning_template_version(
                ctx,
                
                
                **{"templateName": template_name, "templateBody": template_body, "setAsDefault": set_as_default}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iot.describe_provisioning_template_version(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, template_name: Text, version_id: int)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a fleet provisioning template version.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        template_name(Text): The name of the fleet provisioning template version to delete.
        version_id(int): The fleet provisioning template version ID to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iot.provisioning_template_version.absent:
                - name: value
                - template_name: value
                - version_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iot.provisioning_template_version.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iot.describe_provisioning_template_version(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iot.delete_provisioning_template_version(
                ctx,
                
                
                **{"templateName": template_name, "versionId": version_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iot.describe_provisioning_template_version(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

