"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iot.create_thing_group
hub.exec.boto3.client.iot.delete_thing_group
hub.exec.boto3.client.iot.describe_thing_group
hub.exec.boto3.client.iot.list_thing_groups
hub.exec.boto3.client.iot.update_thing_group
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, thing_group_name: Text, parent_group_name: Text = None, thing_group_properties: Dict = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Create a thing group.  This is a control plane operation. See Authorization for information about authorizing
    control plane actions.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        thing_group_name(Text): The thing group name to create.
        parent_group_name(Text, optional): The name of the parent thing group. Defaults to None.
        thing_group_properties(Dict, optional): The thing group properties. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the thing group. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iot.thing_group.present:
                - name: value
                - thing_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iot.thing_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iot.describe_thing_group(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iot.create_thing_group(
                ctx,
                
                
                **{"thingGroupName": thing_group_name, "parentGroupName": parent_group_name, "thingGroupProperties": thing_group_properties, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iot.describe_thing_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, thing_group_name: Text, expected_version: int = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a thing group.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        thing_group_name(Text): The name of the thing group to delete.
        expected_version(int, optional): The expected version of the thing group to delete. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iot.thing_group.absent:
                - name: value
                - thing_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iot.thing_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iot.describe_thing_group(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iot.delete_thing_group(
                ctx,
                
                
                **{"thingGroupName": thing_group_name, "expectedVersion": expected_version}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iot.describe_thing_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

