"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iot.confirm_topic_rule_destination
hub.exec.boto3.client.iot.create_topic_rule_destination
hub.exec.boto3.client.iot.delete_topic_rule_destination
hub.exec.boto3.client.iot.get_topic_rule_destination
hub.exec.boto3.client.iot.list_topic_rule_destinations
hub.exec.boto3.client.iot.update_topic_rule_destination
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, destination_configuration: Dict)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a topic rule destination. The destination must be confirmed prior to use.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        destination_configuration(Dict): The topic rule destination configuration.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iot.topic_rule_destination.present:
                - name: value
                - destination_configuration: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iot.topic_rule_destination.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iot.get_topic_rule_destination(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iot.create_topic_rule_destination(
                ctx,
                
                
                **{"destinationConfiguration": destination_configuration}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iot.get_topic_rule_destination(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a topic rule destination.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        arn(Text): The ARN of the topic rule destination to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iot.topic_rule_destination.absent:
                - name: value
                - arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iot.topic_rule_destination.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iot.get_topic_rule_destination(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iot.delete_topic_rule_destination(
                ctx,
                
                
                **{"arn": arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iot.get_topic_rule_destination(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

