"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iot1click_projects.create_placement
hub.exec.boto3.client.iot1click_projects.delete_placement
hub.exec.boto3.client.iot1click_projects.describe_placement
hub.exec.boto3.client.iot1click_projects.list_placements
hub.exec.boto3.client.iot1click_projects.update_placement
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, placement_name: Text, project_name: Text, attributes: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an empty placement.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        placement_name(Text): The name of the placement to be created.
        project_name(Text): The name of the project in which to create the placement.
        attributes(Dict, optional): Optional user-defined key/value pairs providing contextual data (such as location or function)
            for the placement. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iot1click_projects.placement.present:
                - name: value
                - placement_name: value
                - project_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iot1click_projects.placement.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iot1click_projects.describe_placement(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iot1click_projects.create_placement(
                ctx,
                
                
                **{"placementName": placement_name, "projectName": project_name, "attributes": attributes}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iot1click_projects.describe_placement(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, placement_name: Text, project_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a placement. To delete a placement, it must not have any devices associated with it.  When you delete a
    placement, all associated data becomes irretrievable.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        placement_name(Text): The name of the empty placement to delete.
        project_name(Text): The project containing the empty placement to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iot1click_projects.placement.absent:
                - name: value
                - placement_name: value
                - project_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iot1click_projects.placement.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iot1click_projects.describe_placement(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iot1click_projects.delete_placement(
                ctx,
                
                
                **{"placementName": placement_name, "projectName": project_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iot1click_projects.describe_placement(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

