"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iotanalytics.create_dataset_content
hub.exec.boto3.client.iotanalytics.delete_dataset_content
hub.exec.boto3.client.iotanalytics.get_dataset_content
hub.exec.boto3.client.iotanalytics.list_dataset_contents
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, dataset_name: Text, version_id: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates the content of a dataset by applying a queryAction (a SQL query) or a containerAction (executing a
    containerized application).

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        dataset_name(Text): The name of the dataset.
        version_id(Text, optional): The version ID of the dataset content. To specify versionId for a dataset content, the dataset
            must use a DeltaTimer filter. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iotanalytics.dataset_content.present:
                - name: value
                - dataset_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotanalytics.dataset_content.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iotanalytics.get_dataset_content(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iotanalytics.create_dataset_content(
                ctx,
                
                
                **{"datasetName": dataset_name, "versionId": version_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iotanalytics.get_dataset_content(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, dataset_name: Text, version_id: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the content of the specified dataset.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        dataset_name(Text): The name of the dataset whose content is deleted.
        version_id(Text, optional): The version of the dataset whose content is deleted. You can also use the strings "$LATEST" or
            "$LATEST_SUCCEEDED" to delete the latest or latest successfully completed data set. If not
            specified, "$LATEST_SUCCEEDED" is the default. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iotanalytics.dataset_content.absent:
                - name: value
                - dataset_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotanalytics.dataset_content.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iotanalytics.get_dataset_content(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iotanalytics.delete_dataset_content(
                ctx,
                
                
                **{"datasetName": dataset_name, "versionId": version_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iotanalytics.get_dataset_content(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

