"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iotanalytics.create_pipeline
hub.exec.boto3.client.iotanalytics.delete_pipeline
hub.exec.boto3.client.iotanalytics.describe_pipeline
hub.exec.boto3.client.iotanalytics.list_pipelines
hub.exec.boto3.client.iotanalytics.update_pipeline
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, pipeline_name: Text, pipeline_activities: List, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a pipeline. A pipeline consumes messages from a channel and allows you to process the messages before
    storing them in a data store. You must specify both a channel and a datastore activity and, optionally, as many
    as 23 additional activities in the pipelineActivities array.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        pipeline_name(Text): The name of the pipeline.
        pipeline_activities(List): A list of PipelineActivity objects. Activities perform transformations on your messages, such as
            removing, renaming or adding message attributes; filtering messages based on attribute values;
            invoking your Lambda unctions on messages for advanced processing; or performing mathematical
            transformations to normalize device data. The list can be 2-25 PipelineActivity objects and must
            contain both a channel and a datastore activity. Each entry in the list must contain only one
            activity. For example:  pipelineActivities = [ { "channel": { ... } }, { "lambda": { ... } },
            ... ].
        tags(List, optional): Metadata which can be used to manage the pipeline. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iotanalytics.pipeline.present:
                - name: value
                - pipeline_name: value
                - pipeline_activities: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotanalytics.pipeline.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iotanalytics.describe_pipeline(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iotanalytics.create_pipeline(
                ctx,
                
                
                **{"pipelineName": pipeline_name, "pipelineActivities": pipeline_activities, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iotanalytics.describe_pipeline(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, pipeline_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the specified pipeline.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        pipeline_name(Text): The name of the pipeline to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iotanalytics.pipeline.absent:
                - name: value
                - pipeline_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotanalytics.pipeline.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iotanalytics.describe_pipeline(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iotanalytics.delete_pipeline(
                ctx,
                
                
                **{"pipelineName": pipeline_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iotanalytics.describe_pipeline(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

