"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iotdeviceadvisor.create_suite_definition
hub.exec.boto3.client.iotdeviceadvisor.delete_suite_definition
hub.exec.boto3.client.iotdeviceadvisor.get_suite_definition
hub.exec.boto3.client.iotdeviceadvisor.list_suite_definitions
hub.exec.boto3.client.iotdeviceadvisor.update_suite_definition
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, suite_definition_configuration: Dict = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a Device Advisor test suite.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        suite_definition_configuration(Dict, optional): Creates a Device Advisor test suite with suite definition configuration. Defaults to None.
        tags(Dict, optional): The tags to be attached to the suite definition. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iotdeviceadvisor.suite_definition.present:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotdeviceadvisor.suite_definition.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iotdeviceadvisor.get_suite_definition(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iotdeviceadvisor.create_suite_definition(
                ctx,
                
                
                **{"suiteDefinitionConfiguration": suite_definition_configuration, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iotdeviceadvisor.get_suite_definition(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, suite_definition_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a Device Advisor test suite.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        suite_definition_id(Text): Suite definition Id of the test suite to be deleted.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iotdeviceadvisor.suite_definition.absent:
                - name: value
                - suite_definition_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotdeviceadvisor.suite_definition.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iotdeviceadvisor.get_suite_definition(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iotdeviceadvisor.delete_suite_definition(
                ctx,
                
                
                **{"suiteDefinitionId": suite_definition_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iotdeviceadvisor.get_suite_definition(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

