"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iotevents.create_input
hub.exec.boto3.client.iotevents.delete_input
hub.exec.boto3.client.iotevents.describe_input
hub.exec.boto3.client.iotevents.list_inputs
hub.exec.boto3.client.iotevents.update_input
"""



from typing import *
import dict_tools.differ as differ


__virtualname__ = "input"
async def present(hub, ctx, name: Text, input_name: Text, input_definition: Dict, input_description: Text = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an input.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        input_name(Text): The name you want to give to the input.
        input_description(Text, optional): A brief description of the input. Defaults to None.
        input_definition(Dict): The definition of the input.
        tags(List, optional): Metadata that can be used to manage the input. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iotevents.input_.present:
                - name: value
                - input_name: value
                - input_definition: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotevents.input.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iotevents.describe_input(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iotevents.create_input(
                ctx,
                
                
                **{"inputName": input_name, "inputDescription": input_description, "inputDefinition": input_definition, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iotevents.describe_input(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, input_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an input.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        input_name(Text): The name of the input to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iotevents.input_.absent:
                - name: value
                - input_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotevents.input.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iotevents.describe_input(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iotevents.delete_input(
                ctx,
                
                
                **{"inputName": input_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iotevents.describe_input(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

