"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iotsitewise.create_dashboard
hub.exec.boto3.client.iotsitewise.delete_dashboard
hub.exec.boto3.client.iotsitewise.describe_dashboard
hub.exec.boto3.client.iotsitewise.list_dashboards
hub.exec.boto3.client.iotsitewise.update_dashboard
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, project_id: Text, dashboard_name: Text, dashboard_definition: Text, dashboard_description: Text = None, client_token: Text = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a dashboard in an IoT SiteWise Monitor project.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        project_id(Text): The ID of the project in which to create the dashboard.
        dashboard_name(Text): A friendly name for the dashboard.
        dashboard_description(Text, optional): A description for the dashboard. Defaults to None.
        dashboard_definition(Text): The dashboard definition specified in a JSON literal. For detailed information, see Creating
            dashboards (CLI) in the IoT SiteWise User Guide.
        client_token(Text, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the
            request. Don't reuse this client token if a new idempotent request is required. Defaults to None.
        tags(Dict, optional): A list of key-value pairs that contain metadata for the dashboard. For more information, see
            Tagging your IoT SiteWise resources in the IoT SiteWise User Guide. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iotsitewise.dashboard.present:
                - name: value
                - project_id: value
                - dashboard_name: value
                - dashboard_definition: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotsitewise.dashboard.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iotsitewise.describe_dashboard(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iotsitewise.create_dashboard(
                ctx,
                
                
                **{"projectId": project_id, "dashboardName": dashboard_name, "dashboardDescription": dashboard_description, "dashboardDefinition": dashboard_definition, "clientToken": client_token, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iotsitewise.describe_dashboard(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, dashboard_id: Text, client_token: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a dashboard from IoT SiteWise Monitor.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        dashboard_id(Text): The ID of the dashboard to delete.
        client_token(Text, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the
            request. Don't reuse this client token if a new idempotent request is required. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iotsitewise.dashboard.absent:
                - name: value
                - dashboard_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotsitewise.dashboard.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iotsitewise.describe_dashboard(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iotsitewise.delete_dashboard(
                ctx,
                
                
                **{"dashboardId": dashboard_id, "clientToken": client_token}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iotsitewise.describe_dashboard(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

