"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iotwireless.create_wireless_device
hub.exec.boto3.client.iotwireless.delete_wireless_device
hub.exec.boto3.client.iotwireless.get_wireless_device
hub.exec.boto3.client.iotwireless.list_wireless_devices
hub.exec.boto3.client.iotwireless.test_wireless_device
hub.exec.boto3.client.iotwireless.update_wireless_device
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, type_: Text, destination_name: Text, name: Text = None, description: Text = None, client_request_token: Text = None, lo_ra_wan: Dict = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Provisions a wireless device.

    Args:
        name(Text, optional): The name of the new resource. Defaults to None.
        type_(Text): The wireless device type.
        description(Text, optional): The description of the new resource. Defaults to None.
        destination_name(Text): The name of the destination to assign to the new wireless device.
        client_request_token(Text, optional): Each resource must have a unique client request token. If you try to create a new resource with
            the same token as a resource that already exists, an exception occurs. If you omit this value,
            AWS SDKs will automatically generate a unique client request. Defaults to None.
        lo_ra_wan(Dict, optional): The device configuration information to use to create the wireless device. Defaults to None.
        tags(List, optional): The tags to attach to the new wireless device. Tags are metadata that you can use to manage a
            resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iotwireless.wireless_device.present:
                - type_: value
                - destination_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotwireless.wireless_device.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iotwireless.get_wireless_device(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iotwireless.create_wireless_device(
                ctx,
                
                
                **{"Name": name, "Type": type_, "Description": description, "DestinationName": destination_name, "ClientRequestToken": client_request_token, "LoRaWAN": lo_ra_wan, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iotwireless.get_wireless_device(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, id_: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a wireless device.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        id_(Text): The ID of the resource to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iotwireless.wireless_device.absent:
                - name: value
                - id_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotwireless.wireless_device.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iotwireless.get_wireless_device(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iotwireless.delete_wireless_device(
                ctx,
                
                
                **{"Id": id_}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iotwireless.get_wireless_device(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

