"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iotwireless.create_wireless_gateway_task
hub.exec.boto3.client.iotwireless.delete_wireless_gateway_task
hub.exec.boto3.client.iotwireless.get_wireless_gateway_task
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, id_: Text, wireless_gateway_task_definition_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a task for a wireless gateway.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        id_(Text): The ID of the resource to update.
        wireless_gateway_task_definition_id(Text): The ID of the WirelessGatewayTaskDefinition.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iotwireless.wireless_gateway_task.present:
                - name: value
                - id_: value
                - wireless_gateway_task_definition_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotwireless.wireless_gateway_task.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iotwireless.get_wireless_gateway_task(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iotwireless.create_wireless_gateway_task(
                ctx,
                
                
                **{"Id": id_, "WirelessGatewayTaskDefinitionId": wireless_gateway_task_definition_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iotwireless.get_wireless_gateway_task(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, id_: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a wireless gateway task.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        id_(Text): The ID of the resource to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iotwireless.wireless_gateway_task.absent:
                - name: value
                - id_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotwireless.wireless_gateway_task.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iotwireless.get_wireless_gateway_task(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iotwireless.delete_wireless_gateway_task(
                ctx,
                
                
                **{"Id": id_}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iotwireless.get_wireless_gateway_task(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

