"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.iotwireless.create_wireless_gateway_task_definition
hub.exec.boto3.client.iotwireless.delete_wireless_gateway_task_definition
hub.exec.boto3.client.iotwireless.get_wireless_gateway_task_definition
hub.exec.boto3.client.iotwireless.list_wireless_gateway_task_definitions
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, auto_create_tasks: bool, name: Text = None, update: Dict = None, client_request_token: Text = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a gateway task definition.

    Args:
        name(Text, optional): The name of the new resource. Defaults to None.
        auto_create_tasks(bool): Whether to automatically create tasks using this task definition for all gateways with the
            specified current version. If false, the task must me created by calling
            CreateWirelessGatewayTask.
        update(Dict, optional): Information about the gateways to update. Defaults to None.
        client_request_token(Text, optional): Each resource must have a unique client request token. If you try to create a new resource with
            the same token as a resource that already exists, an exception occurs. If you omit this value,
            AWS SDKs will automatically generate a unique client request. Defaults to None.
        tags(List, optional): The tags to attach to the specified resource. Tags are metadata that you can use to manage a
            resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.iotwireless.wireless_gateway_task_definition.present:
                - auto_create_tasks: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotwireless.wireless_gateway_task_definition.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.iotwireless.get_wireless_gateway_task_definition(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.iotwireless.create_wireless_gateway_task_definition(
                ctx,
                
                
                **{"Name": name, "AutoCreateTasks": auto_create_tasks, "Update": update, "ClientRequestToken": client_request_token, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.iotwireless.get_wireless_gateway_task_definition(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, id_: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a wireless gateway task definition. Deleting this task definition does not affect tasks that are
    currently in progress.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        id_(Text): The ID of the resource to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.iotwireless.wireless_gateway_task_definition.absent:
                - name: value
                - id_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.iotwireless.wireless_gateway_task_definition.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.iotwireless.get_wireless_gateway_task_definition(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.iotwireless.delete_wireless_gateway_task_definition(
                ctx,
                
                
                **{"Id": id_}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.iotwireless.get_wireless_gateway_task_definition(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

