"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.kinesisanalyticsv2.create_application_snapshot
hub.exec.boto3.client.kinesisanalyticsv2.delete_application_snapshot
hub.exec.boto3.client.kinesisanalyticsv2.describe_application_snapshot
hub.exec.boto3.client.kinesisanalyticsv2.list_application_snapshots
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, application_name: Text, snapshot_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a snapshot of the application's state data.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        application_name(Text): The name of an existing application.
        snapshot_name(Text): An identifier for the application snapshot.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.kinesisanalyticsv2.application_snapshot.present:
                - name: value
                - application_name: value
                - snapshot_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.kinesisanalyticsv2.application_snapshot.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.kinesisanalyticsv2.describe_application_snapshot(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.kinesisanalyticsv2.create_application_snapshot(
                ctx,
                
                
                **{"ApplicationName": application_name, "SnapshotName": snapshot_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.kinesisanalyticsv2.describe_application_snapshot(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, application_name: Text, snapshot_name: Text, snapshot_creation_timestamp: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a snapshot of application state.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        application_name(Text): The name of an existing application.
        snapshot_name(Text): The identifier for the snapshot delete.
        snapshot_creation_timestamp(Text): The creation timestamp of the application snapshot to delete. You can retrieve this value using
            or .

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.kinesisanalyticsv2.application_snapshot.absent:
                - name: value
                - application_name: value
                - snapshot_name: value
                - snapshot_creation_timestamp: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.kinesisanalyticsv2.application_snapshot.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.kinesisanalyticsv2.describe_application_snapshot(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.kinesisanalyticsv2.delete_application_snapshot(
                ctx,
                
                
                **{"ApplicationName": application_name, "SnapshotName": snapshot_name, "SnapshotCreationTimestamp": snapshot_creation_timestamp}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.kinesisanalyticsv2.describe_application_snapshot(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

