"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.lightsail.allocate_static_ip
hub.exec.boto3.client.lightsail.attach_static_ip
hub.exec.boto3.client.lightsail.detach_static_ip
hub.exec.boto3.client.lightsail.get_static_ips
hub.exec.boto3.client.lightsail.release_static_ip
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, static_ip_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Allocates a static IP address.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        static_ip_name(Text): The name of the static IP address.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.lightsail.static_ip.present:
                - name: value
                - static_ip_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.lightsail.static_ip.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.lightsail.get_static_ips(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.lightsail.allocate_static_ip(
                ctx,
                
                
                **{"staticIpName": static_ip_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.lightsail.get_static_ips(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, static_ip_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a specific static IP from your account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        static_ip_name(Text): The name of the static IP to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.lightsail.static_ip.absent:
                - name: value
                - static_ip_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.lightsail.static_ip.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.lightsail.get_static_ips(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.lightsail.release_static_ip(
                ctx,
                
                
                **{"staticIpName": static_ip_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.lightsail.get_static_ips(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

