"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.macie.associate_member_account
hub.exec.boto3.client.macie.disassociate_member_account
hub.exec.boto3.client.macie.list_member_accounts
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, member_account_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Associates a specified AWS account with Amazon Macie Classic as a member account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        member_account_id(Text): The ID of the AWS account that you want to associate with Amazon Macie Classic as a member
            account.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.macie.member_account.present:
                - name: value
                - member_account_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.macie.member_account.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.macie.list_member_accounts(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.macie.associate_member_account(
                ctx,
                
                
                **{"memberAccountId": member_account_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.macie.list_member_accounts(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, member_account_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Removes the specified member account from Amazon Macie Classic.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        member_account_id(Text): The ID of the member account that you want to remove from Amazon Macie Classic.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.macie.member_account.absent:
                - name: value
                - member_account_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.macie.member_account.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.macie.list_member_accounts(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.macie.disassociate_member_account(
                ctx,
                
                
                **{"memberAccountId": member_account_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.macie.list_member_accounts(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

