"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.macie2.disable_organization_admin_account
hub.exec.boto3.client.macie2.enable_organization_admin_account
hub.exec.boto3.client.macie2.list_organization_admin_accounts
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, admin_account_id: Text, client_token: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Designates an account as the delegated Amazon Macie administrator account for an Amazon Web Services
    organization.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        admin_account_id(Text): The Amazon Web Services account ID for the account to designate as the delegated Amazon Macie
            administrator account for the organization.
        client_token(Text, optional): A unique, case-sensitive token that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.macie2.organization_admin_account.present:
                - name: value
                - admin_account_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.macie2.organization_admin_account.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.macie2.list_organization_admin_accounts(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.macie2.enable_organization_admin_account(
                ctx,
                
                
                **{"adminAccountId": admin_account_id, "clientToken": client_token}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.macie2.list_organization_admin_accounts(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, admin_account_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Disables an account as the delegated Amazon Macie administrator account for an Amazon Web Services organization.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        admin_account_id(Text): The Amazon Web Services account ID of the delegated Amazon Macie administrator account.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.macie2.organization_admin_account.absent:
                - name: value
                - admin_account_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.macie2.organization_admin_account.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.macie2.list_organization_admin_accounts(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.macie2.disable_organization_admin_account(
                ctx,
                
                
                **{"adminAccountId": admin_account_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.macie2.list_organization_admin_accounts(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

