"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.medialive.accept_input_device_transfer
hub.exec.boto3.client.medialive.cancel_input_device_transfer
hub.exec.boto3.client.medialive.list_input_device_transfers
hub.exec.boto3.client.medialive.reject_input_device_transfer
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, input_device_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Accept an incoming input device transfer. The ownership of the device will transfer to your AWS account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        input_device_id(Text): The unique ID of the input device to accept. For example, hd-123456789abcdef.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.medialive.input_device_transfer.present:
                - name: value
                - input_device_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.medialive.input_device_transfer.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.medialive.list_input_device_transfers(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.medialive.accept_input_device_transfer(
                ctx,
                
                
                **{"InputDeviceId": input_device_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.medialive.list_input_device_transfers(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, input_device_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Reject the transfer of the specified input device to your AWS account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        input_device_id(Text): The unique ID of the input device to reject. For example, hd-123456789abcdef.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.medialive.input_device_transfer.absent:
                - name: value
                - input_device_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.medialive.input_device_transfer.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.medialive.list_input_device_transfers(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.medialive.reject_input_device_transfer(
                ctx,
                
                
                **{"InputDeviceId": input_device_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.medialive.list_input_device_transfers(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

