"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.medialive.create_input_security_group
hub.exec.boto3.client.medialive.delete_input_security_group
hub.exec.boto3.client.medialive.describe_input_security_group
hub.exec.boto3.client.medialive.list_input_security_groups
hub.exec.boto3.client.medialive.update_input_security_group
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, tags: Dict = None, whitelist_rules: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a Input Security Group

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        tags(Dict, optional): A collection of key-value pairs. Defaults to None.
        whitelist_rules(List, optional): List of IPv4 CIDR addresses to whitelist. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.medialive.input_security_group.present:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.medialive.input_security_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.medialive.describe_input_security_group(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.medialive.create_input_security_group(
                ctx,
                
                
                **{"Tags": tags, "WhitelistRules": whitelist_rules}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.medialive.describe_input_security_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, input_security_group_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an Input Security Group

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        input_security_group_id(Text): The Input Security Group to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.medialive.input_security_group.absent:
                - name: value
                - input_security_group_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.medialive.input_security_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.medialive.describe_input_security_group(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.medialive.delete_input_security_group(
                ctx,
                
                
                **{"InputSecurityGroupId": input_security_group_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.medialive.describe_input_security_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

