"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.medialive.create_multiplex
hub.exec.boto3.client.medialive.delete_multiplex
hub.exec.boto3.client.medialive.describe_multiplex
hub.exec.boto3.client.medialive.list_multiplexes
hub.exec.boto3.client.medialive.start_multiplex
hub.exec.boto3.client.medialive.stop_multiplex
hub.exec.boto3.client.medialive.update_multiplex
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, availability_zones: List, multiplex_settings: Dict, request_id: Text, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Create a new multiplex.

    Args:
        name(Text): Name of multiplex.
        availability_zones(List): A list of availability zones for the multiplex. You must specify exactly two.
        multiplex_settings(Dict): Configuration for a multiplex event.
        request_id(Text): Unique request ID. This prevents retries from creating multiple resources.
        tags(Dict, optional): A collection of key-value pairs. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.medialive.multiplex.present:
                - name: value
                - availability_zones: value
                - multiplex_settings: value
                - request_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.medialive.multiplex.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.medialive.describe_multiplex(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.medialive.create_multiplex(
                ctx,
                
                
                **{"Name": name, "AvailabilityZones": availability_zones, "MultiplexSettings": multiplex_settings, "RequestId": request_id, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.medialive.describe_multiplex(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, multiplex_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Delete a multiplex. The multiplex must be idle.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        multiplex_id(Text): The ID of the multiplex.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.medialive.multiplex.absent:
                - name: value
                - multiplex_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.medialive.multiplex.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.medialive.describe_multiplex(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.medialive.delete_multiplex(
                ctx,
                
                
                **{"MultiplexId": multiplex_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.medialive.describe_multiplex(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

