"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.medialive.create_multiplex_program
hub.exec.boto3.client.medialive.delete_multiplex_program
hub.exec.boto3.client.medialive.describe_multiplex_program
hub.exec.boto3.client.medialive.list_multiplex_programs
hub.exec.boto3.client.medialive.update_multiplex_program
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, multiplex_id: Text, multiplex_program_settings: Dict, program_name: Text, request_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Create a new program in the multiplex.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        multiplex_id(Text): ID of the multiplex where the program is to be created.
        multiplex_program_settings(Dict): The settings for this multiplex program.
        program_name(Text): Name of multiplex program.
        request_id(Text): Unique request ID. This prevents retries from creating multiple resources.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.medialive.multiplex_program.present:
                - name: value
                - multiplex_id: value
                - multiplex_program_settings: value
                - program_name: value
                - request_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.medialive.multiplex_program.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.medialive.describe_multiplex_program(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.medialive.create_multiplex_program(
                ctx,
                
                
                **{"MultiplexId": multiplex_id, "MultiplexProgramSettings": multiplex_program_settings, "ProgramName": program_name, "RequestId": request_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.medialive.describe_multiplex_program(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, multiplex_id: Text, program_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Delete a program from a multiplex.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        multiplex_id(Text): The ID of the multiplex that the program belongs to.
        program_name(Text): The multiplex program name.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.medialive.multiplex_program.absent:
                - name: value
                - multiplex_id: value
                - program_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.medialive.multiplex_program.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.medialive.describe_multiplex_program(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.medialive.delete_multiplex_program(
                ctx,
                
                
                **{"MultiplexId": multiplex_id, "ProgramName": program_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.medialive.describe_multiplex_program(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

