"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.mediapackage_vod.create_packaging_configuration
hub.exec.boto3.client.mediapackage_vod.delete_packaging_configuration
hub.exec.boto3.client.mediapackage_vod.describe_packaging_configuration
hub.exec.boto3.client.mediapackage_vod.list_packaging_configurations
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, id_: Text, packaging_group_id: Text, cmaf_package: Dict = None, dash_package: Dict = None, hls_package: Dict = None, mss_package: Dict = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new MediaPackage VOD PackagingConfiguration resource.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        cmaf_package(Dict, optional): A CMAF packaging configuration. Defaults to None.
        dash_package(Dict, optional): A Dynamic Adaptive Streaming over HTTP (DASH) packaging configuration. Defaults to None.
        hls_package(Dict, optional): An HTTP Live Streaming (HLS) packaging configuration. Defaults to None.
        id_(Text): The ID of the PackagingConfiguration.
        mss_package(Dict, optional): A Microsoft Smooth Streaming (MSS) PackagingConfiguration. Defaults to None.
        packaging_group_id(Text): The ID of a PackagingGroup.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.mediapackage_vod.packaging_configuration.present:
                - name: value
                - id_: value
                - packaging_group_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.mediapackage_vod.packaging_configuration.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.mediapackage_vod.describe_packaging_configuration(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.mediapackage_vod.create_packaging_configuration(
                ctx,
                
                
                **{"CmafPackage": cmaf_package, "DashPackage": dash_package, "HlsPackage": hls_package, "Id": id_, "MssPackage": mss_package, "PackagingGroupId": packaging_group_id, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.mediapackage_vod.describe_packaging_configuration(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, id_: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a MediaPackage VOD PackagingConfiguration resource.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        id_(Text): The ID of the MediaPackage VOD PackagingConfiguration resource to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.mediapackage_vod.packaging_configuration.absent:
                - name: value
                - id_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.mediapackage_vod.packaging_configuration.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.mediapackage_vod.describe_packaging_configuration(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.mediapackage_vod.delete_packaging_configuration(
                ctx,
                
                
                **{"Id": id_}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.mediapackage_vod.describe_packaging_configuration(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

