"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.mediapackage_vod.create_packaging_group
hub.exec.boto3.client.mediapackage_vod.delete_packaging_group
hub.exec.boto3.client.mediapackage_vod.describe_packaging_group
hub.exec.boto3.client.mediapackage_vod.list_packaging_groups
hub.exec.boto3.client.mediapackage_vod.update_packaging_group
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, id_: Text, authorization: Dict = None, egress_access_logs: Dict = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new MediaPackage VOD PackagingGroup resource.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        authorization(Dict, optional): CDN Authorization credentials. Defaults to None.
        egress_access_logs(Dict, optional): Configure egress access logging. Defaults to None.
        id_(Text): The ID of the PackagingGroup.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.mediapackage_vod.packaging_group.present:
                - name: value
                - id_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.mediapackage_vod.packaging_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.mediapackage_vod.describe_packaging_group(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.mediapackage_vod.create_packaging_group(
                ctx,
                
                
                **{"Authorization": authorization, "EgressAccessLogs": egress_access_logs, "Id": id_, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.mediapackage_vod.describe_packaging_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, id_: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a MediaPackage VOD PackagingGroup resource.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        id_(Text): The ID of the MediaPackage VOD PackagingGroup resource to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.mediapackage_vod.packaging_group.absent:
                - name: value
                - id_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.mediapackage_vod.packaging_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.mediapackage_vod.describe_packaging_group(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.mediapackage_vod.delete_packaging_group(
                ctx,
                
                
                **{"Id": id_}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.mediapackage_vod.describe_packaging_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

