"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.mediatailor.create_channel
hub.exec.boto3.client.mediatailor.delete_channel
hub.exec.boto3.client.mediatailor.describe_channel
hub.exec.boto3.client.mediatailor.list_channels
hub.exec.boto3.client.mediatailor.start_channel
hub.exec.boto3.client.mediatailor.stop_channel
hub.exec.boto3.client.mediatailor.update_channel
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, channel_name: Text, outputs: List, playback_mode: Text, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a channel.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        channel_name(Text): The identifier for the channel you are working on.
        outputs(List): The channel's output properties.
        playback_mode(Text): The type of playback mode for this channel. The only supported value is LOOP.
        tags(Dict, optional): The tags to assign to the channel. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.mediatailor.channel.present:
                - name: value
                - channel_name: value
                - outputs: value
                - playback_mode: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.mediatailor.channel.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.mediatailor.describe_channel(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.mediatailor.create_channel(
                ctx,
                
                
                **{"ChannelName": channel_name, "Outputs": outputs, "PlaybackMode": playback_mode, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.mediatailor.describe_channel(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, channel_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a channel. You must stop the channel before it can be deleted.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        channel_name(Text): The identifier for the channel you are working on.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.mediatailor.channel.absent:
                - name: value
                - channel_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.mediatailor.channel.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.mediatailor.describe_channel(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.mediatailor.delete_channel(
                ctx,
                
                
                **{"ChannelName": channel_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.mediatailor.describe_channel(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

