"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.mediatailor.delete_channel_policy
hub.exec.boto3.client.mediatailor.get_channel_policy
hub.exec.boto3.client.mediatailor.put_channel_policy
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, channel_name: Text, policy: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an IAM policy for the channel.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        channel_name(Text): The identifier for the channel you are working on.
        policy(Text): Adds an IAM role that determines the permissions of your channel.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.mediatailor.channel_policy.present:
                - name: value
                - channel_name: value
                - policy: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.mediatailor.channel_policy.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.mediatailor.get_channel_policy(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.mediatailor.put_channel_policy(
                ctx,
                
                
                **{"ChannelName": channel_name, "Policy": policy}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.mediatailor.get_channel_policy(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, channel_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a channel's IAM policy.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        channel_name(Text): The identifier for the channel you are working on.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.mediatailor.channel_policy.absent:
                - name: value
                - channel_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.mediatailor.channel_policy.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.mediatailor.get_channel_policy(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.mediatailor.delete_channel_policy(
                ctx,
                
                
                **{"ChannelName": channel_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.mediatailor.get_channel_policy(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

