"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.mediatailor.create_source_location
hub.exec.boto3.client.mediatailor.delete_source_location
hub.exec.boto3.client.mediatailor.describe_source_location
hub.exec.boto3.client.mediatailor.list_source_locations
hub.exec.boto3.client.mediatailor.update_source_location
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, http_configuration: Dict, source_location_name: Text, access_configuration: Dict = None, default_segment_delivery_configuration: Dict = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a source location on a specific channel.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        access_configuration(Dict, optional): Access configuration parameters. Configures the type of authentication used to access content
            from your source location. Defaults to None.
        default_segment_delivery_configuration(Dict, optional): The optional configuration for the server that serves segments. Defaults to None.
        http_configuration(Dict): The source's HTTP package configurations.
        source_location_name(Text): The identifier for the source location you are working on.
        tags(Dict, optional): The tags to assign to the source location. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.mediatailor.source_location.present:
                - name: value
                - http_configuration: value
                - source_location_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.mediatailor.source_location.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.mediatailor.describe_source_location(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.mediatailor.create_source_location(
                ctx,
                
                
                **{"AccessConfiguration": access_configuration, "DefaultSegmentDeliveryConfiguration": default_segment_delivery_configuration, "HttpConfiguration": http_configuration, "SourceLocationName": source_location_name, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.mediatailor.describe_source_location(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, source_location_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a source location on a specific channel.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        source_location_name(Text): The identifier for the source location you are working on.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.mediatailor.source_location.absent:
                - name: value
                - source_location_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.mediatailor.source_location.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.mediatailor.describe_source_location(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.mediatailor.delete_source_location(
                ctx,
                
                
                **{"SourceLocationName": source_location_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.mediatailor.describe_source_location(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

