"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.neptune.create_db_subnet_group
hub.exec.boto3.client.neptune.delete_db_subnet_group
hub.exec.boto3.client.neptune.describe_db_subnet_groups
hub.exec.boto3.client.neptune.modify_db_subnet_group
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, db_subnet_group_name: Text, db_subnet_group_description: Text, subnet_ids: List, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new DB subnet group. DB subnet groups must contain at least one subnet in at least two AZs in the
    Amazon Region.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        db_subnet_group_name(Text): The name for the DB subnet group. This value is stored as a lowercase string. Constraints: Must
            contain no more than 255 letters, numbers, periods, underscores, spaces, or hyphens. Must not be
            default. Example: mySubnetgroup.
        db_subnet_group_description(Text): The description for the DB subnet group.
        subnet_ids(List): The EC2 Subnet IDs for the DB subnet group.
        tags(List, optional): The tags to be assigned to the new DB subnet group. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.neptune.db_subnet_group.present:
                - name: value
                - db_subnet_group_name: value
                - db_subnet_group_description: value
                - subnet_ids: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.neptune.db_subnet_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.neptune.describe_db_subnet_groups(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.neptune.create_db_subnet_group(
                ctx,
                
                
                **{"DBSubnetGroupName": db_subnet_group_name, "DBSubnetGroupDescription": db_subnet_group_description, "SubnetIds": subnet_ids, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.neptune.describe_db_subnet_groups(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, db_subnet_group_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a DB subnet group.  The specified database subnet group must not be associated with any DB instances.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        db_subnet_group_name(Text): The name of the database subnet group to delete.  You can't delete the default subnet group.
            Constraints: Constraints: Must match the name of an existing DBSubnetGroup. Must not be default.
            Example: mySubnetgroup.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.neptune.db_subnet_group.absent:
                - name: value
                - db_subnet_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.neptune.db_subnet_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.neptune.describe_db_subnet_groups(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.neptune.delete_db_subnet_group(
                ctx,
                
                
                **{"DBSubnetGroupName": db_subnet_group_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.neptune.describe_db_subnet_groups(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

