"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.networkmanager.associate_link
hub.exec.boto3.client.networkmanager.create_link
hub.exec.boto3.client.networkmanager.delete_link
hub.exec.boto3.client.networkmanager.disassociate_link
hub.exec.boto3.client.networkmanager.get_links
hub.exec.boto3.client.networkmanager.update_link
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, global_network_id: Text, bandwidth: Dict, site_id: Text, description: Text = None, type_: Text = None, provider: Text = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new link for a specified site.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        global_network_id(Text): The ID of the global network.
        description(Text, optional): A description of the link. Length Constraints: Maximum length of 256 characters. Defaults to None.
        type_(Text, optional): The type of the link. Constraints: Cannot include the following characters: | \ ^ Length
            Constraints: Maximum length of 128 characters. Defaults to None.
        bandwidth(Dict):  The upload speed and download speed in Mbps.
        provider(Text, optional): The provider of the link. Constraints: Cannot include the following characters: | \ ^ Length
            Constraints: Maximum length of 128 characters. Defaults to None.
        site_id(Text): The ID of the site.
        tags(List, optional): The tags to apply to the resource during creation. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.networkmanager.link.present:
                - name: value
                - global_network_id: value
                - bandwidth: value
                - site_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.networkmanager.link.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.networkmanager.get_links(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.networkmanager.create_link(
                ctx,
                
                
                **{"GlobalNetworkId": global_network_id, "Description": description, "Type": type_, "Bandwidth": bandwidth, "Provider": provider, "SiteId": site_id, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.networkmanager.get_links(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, global_network_id: Text, link_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an existing link. You must first disassociate the link from any devices and customer gateways.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        global_network_id(Text): The ID of the global network.
        link_id(Text): The ID of the link.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.networkmanager.link.absent:
                - name: value
                - global_network_id: value
                - link_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.networkmanager.link.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.networkmanager.get_links(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.networkmanager.delete_link(
                ctx,
                
                
                **{"GlobalNetworkId": global_network_id, "LinkId": link_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.networkmanager.get_links(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

