"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.nimble.create_launch_profile
hub.exec.boto3.client.nimble.delete_launch_profile
hub.exec.boto3.client.nimble.get_launch_profile
hub.exec.boto3.client.nimble.list_launch_profiles
hub.exec.boto3.client.nimble.update_launch_profile
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, ec2_subnet_ids: List, launch_profile_protocol_versions: List, stream_configuration: Dict, studio_component_ids: List, studio_id: Text, client_token: Text = None, description: Text = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Create a launch profile.

    Args:
        name(Text): The name for the launch profile.
        client_token(Text, optional): To make an idempotent API request using one of these actions, specify a client token in the
            request. You should not reuse the same client token for other API requests. If you retry a
            request that completed successfully using the same client token and the same parameters, the
            retry succeeds without performing any further actions. If you retry a successful request using
            the same client token, but one or more of the parameters are different, the retry fails with a
            ValidationException error. Defaults to None.
        description(Text, optional): The description. Defaults to None.
        ec2_subnet_ids(List): .
        launch_profile_protocol_versions(List): The version number of the protocol that is used by the launch profile. The only valid version is
            "2021-03-31".
        stream_configuration(Dict): A configuration for a streaming session.
        studio_component_ids(List): Unique identifiers for a collection of studio components that can be used with this launch
            profile.
        studio_id(Text): The studio ID.
        tags(Dict, optional): A collection of labels, in the form of key:value pairs, that apply to this resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.nimble.launch_profile.present:
                - name: value
                - ec2_subnet_ids: value
                - launch_profile_protocol_versions: value
                - stream_configuration: value
                - studio_component_ids: value
                - studio_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.nimble.launch_profile.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.nimble.get_launch_profile(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.nimble.create_launch_profile(
                ctx,
                
                
                **{"Name": name, "clientToken": client_token, "description": description, "ec2SubnetIds": ec2_subnet_ids, "launchProfileProtocolVersions": launch_profile_protocol_versions, "streamConfiguration": stream_configuration, "studioComponentIds": studio_component_ids, "studioId": studio_id, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.nimble.get_launch_profile(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, launch_profile_id: Text, studio_id: Text, client_token: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Permanently delete a launch profile.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        client_token(Text, optional): To make an idempotent API request using one of these actions, specify a client token in the
            request. You should not reuse the same client token for other API requests. If you retry a
            request that completed successfully using the same client token and the same parameters, the
            retry succeeds without performing any further actions. If you retry a successful request using
            the same client token, but one or more of the parameters are different, the retry fails with a
            ValidationException error. Defaults to None.
        launch_profile_id(Text): The launch profile ID.
        studio_id(Text): The studio ID.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.nimble.launch_profile.absent:
                - name: value
                - launch_profile_id: value
                - studio_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.nimble.launch_profile.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.nimble.get_launch_profile(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.nimble.delete_launch_profile(
                ctx,
                
                
                **{"clientToken": client_token, "launchProfileId": launch_profile_id, "studioId": studio_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.nimble.get_launch_profile(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

