"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.opsworks.associate_elastic_ip
hub.exec.boto3.client.opsworks.deregister_elastic_ip
hub.exec.boto3.client.opsworks.describe_elastic_ips
hub.exec.boto3.client.opsworks.disassociate_elastic_ip
hub.exec.boto3.client.opsworks.register_elastic_ip
hub.exec.boto3.client.opsworks.update_elastic_ip
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, elastic_ip: Text, instance_id: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Associates one of the stack's registered Elastic IP addresses with a specified instance. The address must first
    be registered with the stack by calling RegisterElasticIp. For more information, see Resource Management.
    Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an
    attached policy that explicitly grants permissions. For more information on user permissions, see Managing User
    Permissions.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        elastic_ip(Text): The Elastic IP address.
        instance_id(Text, optional): The instance ID. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.opsworks.elastic_ip.present:
                - name: value
                - elastic_ip: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.opsworks.elastic_ip.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.opsworks.describe_elastic_ips(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.opsworks.associate_elastic_ip(
                ctx,
                
                
                **{"ElasticIp": elastic_ip, "InstanceId": instance_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.opsworks.describe_elastic_ips(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, elastic_ip: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Disassociates an Elastic IP address from its instance. The address remains registered with the stack. For more
    information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage
    permissions level for the stack, or an attached policy that explicitly grants permissions. For more information
    on user permissions, see Managing User Permissions.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        elastic_ip(Text): The Elastic IP address.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.opsworks.elastic_ip.absent:
                - name: value
                - elastic_ip: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.opsworks.elastic_ip.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.opsworks.describe_elastic_ips(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.opsworks.disassociate_elastic_ip(
                ctx,
                
                
                **{"ElasticIp": elastic_ip}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.opsworks.describe_elastic_ips(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

