"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.outposts.create_outpost
hub.exec.boto3.client.outposts.delete_outpost
hub.exec.boto3.client.outposts.get_outpost
hub.exec.boto3.client.outposts.list_outposts
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, site_id: Text, description: Text = None, availability_zone: Text = None, availability_zone_id: Text = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an Outpost. You can specify AvailabilityZone or AvailabilityZoneId.

    Args:
        name(Text): The name of the Outpost.
        description(Text, optional): The description of the Outpost. Defaults to None.
        site_id(Text): The ID of the site.
        availability_zone(Text, optional): The Availability Zone. Defaults to None.
        availability_zone_id(Text, optional): The ID of the Availability Zone. Defaults to None.
        tags(Dict, optional): The tags to apply to the Outpost. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.outposts.outpost.present:
                - name: value
                - site_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.outposts.outpost.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.outposts.get_outpost(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.outposts.create_outpost(
                ctx,
                
                
                **{"Name": name, "Description": description, "SiteId": site_id, "AvailabilityZone": availability_zone, "AvailabilityZoneId": availability_zone_id, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.outposts.get_outpost(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, outpost_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the Outpost.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        outpost_id(Text): The ID of the Outpost.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.outposts.outpost.absent:
                - name: value
                - outpost_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.outposts.outpost.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.outposts.get_outpost(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.outposts.delete_outpost(
                ctx,
                
                
                **{"OutpostId": outpost_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.outposts.get_outpost(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

