"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.pinpoint.create_app
hub.exec.boto3.client.pinpoint.delete_app
hub.exec.boto3.client.pinpoint.get_apps
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, create_application_request: Dict)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
     Creates an application.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        create_application_request(Dict): Specifies the display name of an application and the tags to associate with the application.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.pinpoint.app.present:
                - name: value
                - create_application_request: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.pinpoint.app.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.pinpoint.get_apps(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.pinpoint.create_app(
                ctx,
                
                
                **{"CreateApplicationRequest": create_application_request}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.pinpoint.get_apps(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, application_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an application.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        application_id(Text): The unique identifier for the application. This identifier is displayed as the Project ID on the
            Amazon Pinpoint console.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.pinpoint.app.absent:
                - name: value
                - application_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.pinpoint.app.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.pinpoint.get_apps(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.pinpoint.delete_app(
                ctx,
                
                
                **{"ApplicationId": application_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.pinpoint.get_apps(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

