"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.pinpoint.create_recommender_configuration
hub.exec.boto3.client.pinpoint.delete_recommender_configuration
hub.exec.boto3.client.pinpoint.get_recommender_configurations
hub.exec.boto3.client.pinpoint.update_recommender_configuration
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, create_recommender_configuration: Dict)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an Amazon Pinpoint configuration for a recommender model.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        create_recommender_configuration(Dict): Specifies Amazon Pinpoint configuration settings for retrieving and processing recommendation
            data from a recommender model.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.pinpoint.recommender_configuration.present:
                - name: value
                - create_recommender_configuration: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.pinpoint.recommender_configuration.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.pinpoint.get_recommender_configurations(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.pinpoint.create_recommender_configuration(
                ctx,
                
                
                **{"CreateRecommenderConfiguration": create_recommender_configuration}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.pinpoint.get_recommender_configurations(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, recommender_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an Amazon Pinpoint configuration for a recommender model.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        recommender_id(Text): The unique identifier for the recommender model configuration. This identifier is displayed as
            the Recommender ID on the Amazon Pinpoint console.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.pinpoint.recommender_configuration.absent:
                - name: value
                - recommender_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.pinpoint.recommender_configuration.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.pinpoint.get_recommender_configurations(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.pinpoint.delete_recommender_configuration(
                ctx,
                
                
                **{"RecommenderId": recommender_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.pinpoint.get_recommender_configurations(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

