"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ram.accept_resource_share_invitation
hub.exec.boto3.client.ram.get_resource_share_invitations
hub.exec.boto3.client.ram.reject_resource_share_invitation
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, resource_share_invitation_arn: Text, client_token: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Accepts an invitation to a resource share from another AWS account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        resource_share_invitation_arn(Text): The Amazon Resource Name (ARN) of the invitation.
        client_token(Text, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ram.resource_share_invitation.present:
                - name: value
                - resource_share_invitation_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ram.resource_share_invitation.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ram.get_resource_share_invitations(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ram.accept_resource_share_invitation(
                ctx,
                
                
                **{"resourceShareInvitationArn": resource_share_invitation_arn, "clientToken": client_token}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ram.get_resource_share_invitations(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, resource_share_invitation_arn: Text, client_token: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Rejects an invitation to a resource share from another AWS account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        resource_share_invitation_arn(Text): The Amazon Resource Name (ARN) of the invitation.
        client_token(Text, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ram.resource_share_invitation.absent:
                - name: value
                - resource_share_invitation_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ram.resource_share_invitation.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ram.get_resource_share_invitations(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ram.reject_resource_share_invitation(
                ctx,
                
                
                **{"resourceShareInvitationArn": resource_share_invitation_arn, "clientToken": client_token}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ram.get_resource_share_invitations(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

