"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.rds.deregister_db_proxy_targets
hub.exec.boto3.client.rds.describe_db_proxy_targets
hub.exec.boto3.client.rds.register_db_proxy_targets
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, db_proxy_name: Text, target_group_name: Text = None, db_instance_identifiers: List = None, db_cluster_identifiers: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Associate one or more DBProxyTarget data structures with a DBProxyTargetGroup.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        db_proxy_name(Text): The identifier of the DBProxy that is associated with the DBProxyTargetGroup.
        target_group_name(Text, optional): The identifier of the DBProxyTargetGroup. Defaults to None.
        db_instance_identifiers(List, optional): One or more DB instance identifiers. Defaults to None.
        db_cluster_identifiers(List, optional): One or more DB cluster identifiers. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.rds.db_proxy_target.present:
                - name: value
                - db_proxy_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.rds.db_proxy_target.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.rds.describe_db_proxy_targets(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.rds.register_db_proxy_targets(
                ctx,
                
                
                **{"DBProxyName": db_proxy_name, "TargetGroupName": target_group_name, "DBInstanceIdentifiers": db_instance_identifiers, "DBClusterIdentifiers": db_cluster_identifiers}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.rds.describe_db_proxy_targets(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, db_proxy_name: Text, target_group_name: Text = None, db_instance_identifiers: List = None, db_cluster_identifiers: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Remove the association between one or more DBProxyTarget data structures and a DBProxyTargetGroup.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        db_proxy_name(Text): The identifier of the DBProxy that is associated with the DBProxyTargetGroup.
        target_group_name(Text, optional): The identifier of the DBProxyTargetGroup. Defaults to None.
        db_instance_identifiers(List, optional): One or more DB instance identifiers. Defaults to None.
        db_cluster_identifiers(List, optional): One or more DB cluster identifiers. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.rds.db_proxy_target.absent:
                - name: value
                - db_proxy_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.rds.db_proxy_target.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.rds.describe_db_proxy_targets(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.rds.deregister_db_proxy_targets(
                ctx,
                
                
                **{"DBProxyName": db_proxy_name, "TargetGroupName": target_group_name, "DBInstanceIdentifiers": db_instance_identifiers, "DBClusterIdentifiers": db_cluster_identifiers}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.rds.describe_db_proxy_targets(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

