"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.rds.create_db_security_group
hub.exec.boto3.client.rds.delete_db_security_group
hub.exec.boto3.client.rds.describe_db_security_groups
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, db_security_group_name: Text, db_security_group_description: Text, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new DB security group. DB security groups control access to a DB instance.  A DB security group
    controls access to EC2-Classic DB instances that are not in a VPC.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        db_security_group_name(Text): The name for the DB security group. This value is stored as a lowercase string. Constraints:
            Must be 1 to 255 letters, numbers, or hyphens.   First character must be a letter   Can't end
            with a hyphen or contain two consecutive hyphens   Must not be "Default"   Example:
            mysecuritygroup.
        db_security_group_description(Text): The description for the DB security group.
        tags(List, optional): Tags to assign to the DB security group. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.rds.db_security_group.present:
                - name: value
                - db_security_group_name: value
                - db_security_group_description: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.rds.db_security_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.rds.describe_db_security_groups(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.rds.create_db_security_group(
                ctx,
                
                
                **{"DBSecurityGroupName": db_security_group_name, "DBSecurityGroupDescription": db_security_group_description, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.rds.describe_db_security_groups(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, db_security_group_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a DB security group.  The specified DB security group must not be associated with any DB instances.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        db_security_group_name(Text): The name of the DB security group to delete.  You can't delete the default DB security group.
            Constraints:   Must be 1 to 255 letters, numbers, or hyphens.   First character must be a letter
            Can't end with a hyphen or contain two consecutive hyphens   Must not be "Default".

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.rds.db_security_group.absent:
                - name: value
                - db_security_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.rds.db_security_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.rds.describe_db_security_groups(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.rds.delete_db_security_group(
                ctx,
                
                
                **{"DBSecurityGroupName": db_security_group_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.rds.describe_db_security_groups(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

