"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.redshift.create_authentication_profile
hub.exec.boto3.client.redshift.delete_authentication_profile
hub.exec.boto3.client.redshift.describe_authentication_profiles
hub.exec.boto3.client.redshift.modify_authentication_profile
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, authentication_profile_name: Text, authentication_profile_content: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an authentication profile with the specified parameters.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        authentication_profile_name(Text): The name of the authentication profile to be created.
        authentication_profile_content(Text): The content of the authentication profile in JSON format. The maximum length of the JSON string
            is determined by a quota for your account.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.redshift.authentication_profile.present:
                - name: value
                - authentication_profile_name: value
                - authentication_profile_content: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.redshift.authentication_profile.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.redshift.describe_authentication_profiles(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.redshift.create_authentication_profile(
                ctx,
                
                
                **{"AuthenticationProfileName": authentication_profile_name, "AuthenticationProfileContent": authentication_profile_content}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.redshift.describe_authentication_profiles(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, authentication_profile_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an authentication profile.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        authentication_profile_name(Text): The name of the authentication profile to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.redshift.authentication_profile.absent:
                - name: value
                - authentication_profile_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.redshift.authentication_profile.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.redshift.describe_authentication_profiles(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.redshift.delete_authentication_profile(
                ctx,
                
                
                **{"AuthenticationProfileName": authentication_profile_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.redshift.describe_authentication_profiles(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

