"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.robomaker.create_robot
hub.exec.boto3.client.robomaker.delete_robot
hub.exec.boto3.client.robomaker.deregister_robot
hub.exec.boto3.client.robomaker.describe_robot
hub.exec.boto3.client.robomaker.list_robots
hub.exec.boto3.client.robomaker.register_robot
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, architecture: Text, greengrass_group_id: Text, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a robot.

    Args:
        name(Text): The name for the robot.
        architecture(Text): The target architecture of the robot.
        greengrass_group_id(Text): The Greengrass group id.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the robot. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.robomaker.robot.present:
                - name: value
                - architecture: value
                - greengrass_group_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.robomaker.robot.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.robomaker.describe_robot(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.robomaker.create_robot(
                ctx,
                
                
                **{"Name": name, "architecture": architecture, "greengrassGroupId": greengrass_group_id, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.robomaker.describe_robot(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, robot: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a robot.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        robot(Text): The Amazon Resource Name (ARN) of the robot.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.robomaker.robot.absent:
                - name: value
                - robot: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.robomaker.robot.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.robomaker.describe_robot(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.robomaker.delete_robot(
                ctx,
                
                
                **{"robot": robot}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.robomaker.describe_robot(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

