"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.robomaker.create_simulation_application
hub.exec.boto3.client.robomaker.delete_simulation_application
hub.exec.boto3.client.robomaker.describe_simulation_application
hub.exec.boto3.client.robomaker.list_simulation_applications
hub.exec.boto3.client.robomaker.update_simulation_application
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, sources: List, simulation_software_suite: Dict, robot_software_suite: Dict, rendering_engine: Dict = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a simulation application.

    Args:
        name(Text): The name of the simulation application.
        sources(List): The sources of the simulation application.
        simulation_software_suite(Dict): The simulation software suite used by the simulation application.
        robot_software_suite(Dict): The robot software suite (ROS distribution) used by the simulation application.
        rendering_engine(Dict, optional): The rendering engine for the simulation application. Defaults to None.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the simulation application. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.robomaker.simulation_application.present:
                - name: value
                - sources: value
                - simulation_software_suite: value
                - robot_software_suite: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.robomaker.simulation_application.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.robomaker.describe_simulation_application(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.robomaker.create_simulation_application(
                ctx,
                
                
                **{"Name": name, "sources": sources, "simulationSoftwareSuite": simulation_software_suite, "robotSoftwareSuite": robot_software_suite, "renderingEngine": rendering_engine, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.robomaker.describe_simulation_application(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, application: Text, application_version: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a simulation application.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        application(Text): The application information for the simulation application to delete.
        application_version(Text, optional): The version of the simulation application to delete. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.robomaker.simulation_application.absent:
                - name: value
                - application: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.robomaker.simulation_application.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.robomaker.describe_simulation_application(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.robomaker.delete_simulation_application(
                ctx,
                
                
                **{"application": application, "applicationVersion": application_version}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.robomaker.describe_simulation_application(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

