"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.robomaker.cancel_world_export_job
hub.exec.boto3.client.robomaker.create_world_export_job
hub.exec.boto3.client.robomaker.describe_world_export_job
hub.exec.boto3.client.robomaker.list_world_export_jobs
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, worlds: List, output_location: Dict, iam_role: Text, client_request_token: Text = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a world export job.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        client_request_token(Text, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        worlds(List): A list of Amazon Resource Names (arns) that correspond to worlds to export.
        output_location(Dict): The output location.
        iam_role(Text): The IAM role that the world export process uses to access the Amazon S3 bucket and put the
            export.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the world export job. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.robomaker.world_export_job.present:
                - name: value
                - worlds: value
                - output_location: value
                - iam_role: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.robomaker.world_export_job.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.robomaker.describe_world_export_job(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.robomaker.create_world_export_job(
                ctx,
                
                
                **{"clientRequestToken": client_request_token, "worlds": worlds, "outputLocation": output_location, "iamRole": iam_role, "tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.robomaker.describe_world_export_job(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, job: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Cancels the specified export job.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        job(Text): The Amazon Resource Name (arn) of the world export job to cancel.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.robomaker.world_export_job.absent:
                - name: value
                - job: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.robomaker.world_export_job.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.robomaker.describe_world_export_job(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.robomaker.cancel_world_export_job(
                ctx,
                
                
                **{"job": job}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.robomaker.describe_world_export_job(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

