"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.route53_recovery_readiness.create_cell
hub.exec.boto3.client.route53_recovery_readiness.delete_cell
hub.exec.boto3.client.route53_recovery_readiness.get_cell
hub.exec.boto3.client.route53_recovery_readiness.list_cells
hub.exec.boto3.client.route53_recovery_readiness.update_cell
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, cell_name: Text, cells: List = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new Cell.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        cell_name(Text): The name of the Cell to create.
        cells(List, optional): A list of Cell arns contained within this Cell (for use in nested Cells, e.g. regions within
            which AZs). Defaults to None.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.route53_recovery_readiness.cell.present:
                - name: value
                - cell_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.route53_recovery_readiness.cell.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.route53_recovery_readiness.get_cell(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.route53_recovery_readiness.create_cell(
                ctx,
                
                
                **{"CellName": cell_name, "Cells": cells, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.route53_recovery_readiness.get_cell(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, cell_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an existing Cell.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        cell_name(Text): The Cell to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.route53_recovery_readiness.cell.absent:
                - name: value
                - cell_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.route53_recovery_readiness.cell.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.route53_recovery_readiness.get_cell(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.route53_recovery_readiness.delete_cell(
                ctx,
                
                
                **{"CellName": cell_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.route53_recovery_readiness.get_cell(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

