"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.route53_recovery_readiness.create_cross_account_authorization
hub.exec.boto3.client.route53_recovery_readiness.delete_cross_account_authorization
hub.exec.boto3.client.route53_recovery_readiness.list_cross_account_authorizations
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, cross_account_authorization: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Create a new cross account readiness authorization.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        cross_account_authorization(Text): The cross account authorization.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.route53_recovery_readiness.cross_account_authorization.present:
                - name: value
                - cross_account_authorization: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.route53_recovery_readiness.cross_account_authorization.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.route53_recovery_readiness.list_cross_account_authorizations(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.route53_recovery_readiness.create_cross_account_authorization(
                ctx,
                
                
                **{"CrossAccountAuthorization": cross_account_authorization}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.route53_recovery_readiness.list_cross_account_authorizations(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, cross_account_authorization: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Delete cross account readiness authorization

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        cross_account_authorization(Text): The cross account authorization.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.route53_recovery_readiness.cross_account_authorization.absent:
                - name: value
                - cross_account_authorization: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.route53_recovery_readiness.cross_account_authorization.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.route53_recovery_readiness.list_cross_account_authorizations(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.route53_recovery_readiness.delete_cross_account_authorization(
                ctx,
                
                
                **{"CrossAccountAuthorization": cross_account_authorization}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.route53_recovery_readiness.list_cross_account_authorizations(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

