"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.route53_recovery_readiness.create_readiness_check
hub.exec.boto3.client.route53_recovery_readiness.delete_readiness_check
hub.exec.boto3.client.route53_recovery_readiness.get_readiness_check
hub.exec.boto3.client.route53_recovery_readiness.list_readiness_checks
hub.exec.boto3.client.route53_recovery_readiness.update_readiness_check
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, readiness_check_name: Text, resource_set_name: Text, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new Readiness Check.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        readiness_check_name(Text): The name of the ReadinessCheck to create.
        resource_set_name(Text): The name of the ResourceSet to check.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.route53_recovery_readiness.readiness_check.present:
                - name: value
                - readiness_check_name: value
                - resource_set_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.route53_recovery_readiness.readiness_check.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.route53_recovery_readiness.get_readiness_check(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.route53_recovery_readiness.create_readiness_check(
                ctx,
                
                
                **{"ReadinessCheckName": readiness_check_name, "ResourceSetName": resource_set_name, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.route53_recovery_readiness.get_readiness_check(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, readiness_check_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an existing Readiness Check.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        readiness_check_name(Text): The ReadinessCheck to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.route53_recovery_readiness.readiness_check.absent:
                - name: value
                - readiness_check_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.route53_recovery_readiness.readiness_check.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.route53_recovery_readiness.get_readiness_check(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.route53_recovery_readiness.delete_readiness_check(
                ctx,
                
                
                **{"ReadinessCheckName": readiness_check_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.route53_recovery_readiness.get_readiness_check(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

