"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.route53_recovery_readiness.create_recovery_group
hub.exec.boto3.client.route53_recovery_readiness.delete_recovery_group
hub.exec.boto3.client.route53_recovery_readiness.get_recovery_group
hub.exec.boto3.client.route53_recovery_readiness.list_recovery_groups
hub.exec.boto3.client.route53_recovery_readiness.update_recovery_group
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, recovery_group_name: Text, cells: List = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new Recovery Group.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        cells(List, optional): A list of Cell arns. Defaults to None.
        recovery_group_name(Text): The name of the RecoveryGroup to create.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.route53_recovery_readiness.recovery_group.present:
                - name: value
                - recovery_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.route53_recovery_readiness.recovery_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.route53_recovery_readiness.get_recovery_group(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.route53_recovery_readiness.create_recovery_group(
                ctx,
                
                
                **{"Cells": cells, "RecoveryGroupName": recovery_group_name, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.route53_recovery_readiness.get_recovery_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, recovery_group_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an existing Recovery Group.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        recovery_group_name(Text): The RecoveryGroup to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.route53_recovery_readiness.recovery_group.absent:
                - name: value
                - recovery_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.route53_recovery_readiness.recovery_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.route53_recovery_readiness.get_recovery_group(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.route53_recovery_readiness.delete_recovery_group(
                ctx,
                
                
                **{"RecoveryGroupName": recovery_group_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.route53_recovery_readiness.get_recovery_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

