"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.route53_recovery_readiness.create_resource_set
hub.exec.boto3.client.route53_recovery_readiness.delete_resource_set
hub.exec.boto3.client.route53_recovery_readiness.get_resource_set
hub.exec.boto3.client.route53_recovery_readiness.list_resource_sets
hub.exec.boto3.client.route53_recovery_readiness.update_resource_set
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, resource_set_name: Text, resource_set_type: Text, resources: List, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new Resource Set.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        resource_set_name(Text): The name of the ResourceSet to create.
        resource_set_type(Text): AWS Resource type of the resources in the ResourceSet.
        resources(List): A list of Resource objects.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.route53_recovery_readiness.resource_set.present:
                - name: value
                - resource_set_name: value
                - resource_set_type: value
                - resources: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.route53_recovery_readiness.resource_set.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.route53_recovery_readiness.get_resource_set(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.route53_recovery_readiness.create_resource_set(
                ctx,
                
                
                **{"ResourceSetName": resource_set_name, "ResourceSetType": resource_set_type, "Resources": resources, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.route53_recovery_readiness.get_resource_set(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, resource_set_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an existing Resource Set.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        resource_set_name(Text): The ResourceSet to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.route53_recovery_readiness.resource_set.absent:
                - name: value
                - resource_set_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.route53_recovery_readiness.resource_set.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.route53_recovery_readiness.get_resource_set(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.route53_recovery_readiness.delete_resource_set(
                ctx,
                
                
                **{"ResourceSetName": resource_set_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.route53_recovery_readiness.get_resource_set(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

