"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.s3control.delete_public_access_block
hub.exec.boto3.client.s3control.get_public_access_block
hub.exec.boto3.client.s3control.put_public_access_block
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, public_access_block_configuration: Dict, account_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates or modifies the PublicAccessBlock configuration for an account. For more information, see  Using Amazon
    S3 block public access. Related actions include:    GetPublicAccessBlock     DeletePublicAccessBlock

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        public_access_block_configuration(Dict): The PublicAccessBlock configuration that you want to apply to the specified account.
        account_id(Text): The account ID for the account whose PublicAccessBlock configuration you want to set.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.s3control.public_access_block.present:
                - name: value
                - public_access_block_configuration: value
                - account_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.s3control.public_access_block.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.s3control.get_public_access_block(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.s3control.put_public_access_block(
                ctx,
                
                
                **{"PublicAccessBlockConfiguration": public_access_block_configuration, "AccountId": account_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.s3control.get_public_access_block(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, account_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Removes the PublicAccessBlock configuration for an account. For more information, see  Using Amazon S3 block
    public access. Related actions include:    GetPublicAccessBlock     PutPublicAccessBlock

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        account_id(Text): The account ID for the account whose PublicAccessBlock configuration you want to remove.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.s3control.public_access_block.absent:
                - name: value
                - account_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.s3control.public_access_block.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.s3control.get_public_access_block(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.s3control.delete_public_access_block(
                ctx,
                
                
                **{"AccountId": account_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.s3control.get_public_access_block(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

