"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.sagemaker.create_app_image_config
hub.exec.boto3.client.sagemaker.delete_app_image_config
hub.exec.boto3.client.sagemaker.describe_app_image_config
hub.exec.boto3.client.sagemaker.list_app_image_configs
hub.exec.boto3.client.sagemaker.update_app_image_config
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, app_image_config_name: Text, tags: List = None, kernel_gateway_image_config: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a configuration for running a SageMaker image as a KernelGateway app. The configuration specifies the
    Amazon Elastic File System (EFS) storage volume on the image, and a list of the kernels in the image.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        app_image_config_name(Text): The name of the AppImageConfig. Must be unique to your account.
        tags(List, optional): A list of tags to apply to the AppImageConfig. Defaults to None.
        kernel_gateway_image_config(Dict, optional): The KernelGatewayImageConfig. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.sagemaker.app_image_config.present:
                - name: value
                - app_image_config_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sagemaker.app_image_config.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.sagemaker.describe_app_image_config(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.sagemaker.create_app_image_config(
                ctx,
                
                
                **{"AppImageConfigName": app_image_config_name, "Tags": tags, "KernelGatewayImageConfig": kernel_gateway_image_config}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.sagemaker.describe_app_image_config(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, app_image_config_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an AppImageConfig.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        app_image_config_name(Text): The name of the AppImageConfig to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.sagemaker.app_image_config.absent:
                - name: value
                - app_image_config_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sagemaker.app_image_config.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.sagemaker.describe_app_image_config(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.sagemaker.delete_app_image_config(
                ctx,
                
                
                **{"AppImageConfigName": app_image_config_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.sagemaker.describe_app_image_config(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

