"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.sagemaker.deregister_devices
hub.exec.boto3.client.sagemaker.describe_device
hub.exec.boto3.client.sagemaker.list_devices
hub.exec.boto3.client.sagemaker.register_devices
hub.exec.boto3.client.sagemaker.update_devices
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, device_fleet_name: Text, devices: List, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Register devices.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        device_fleet_name(Text): The name of the fleet.
        devices(List): A list of devices to register with SageMaker Edge Manager.
        tags(List, optional): The tags associated with devices. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.sagemaker.device.present:
                - name: value
                - device_fleet_name: value
                - devices: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sagemaker.device.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.sagemaker.describe_device(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.sagemaker.register_devices(
                ctx,
                
                
                **{"DeviceFleetName": device_fleet_name, "Devices": devices, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.sagemaker.describe_device(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, device_fleet_name: Text, device_names: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deregisters the specified devices. After you deregister a device, you will need to re-register the devices.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        device_fleet_name(Text): The name of the fleet the devices belong to.
        device_names(List): The unique IDs of the devices.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.sagemaker.device.absent:
                - name: value
                - device_fleet_name: value
                - device_names: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sagemaker.device.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.sagemaker.describe_device(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.sagemaker.deregister_devices(
                ctx,
                
                
                **{"DeviceFleetName": device_fleet_name, "DeviceNames": device_names}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.sagemaker.describe_device(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

