"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.sagemaker.create_device_fleet
hub.exec.boto3.client.sagemaker.delete_device_fleet
hub.exec.boto3.client.sagemaker.describe_device_fleet
hub.exec.boto3.client.sagemaker.list_device_fleets
hub.exec.boto3.client.sagemaker.update_device_fleet
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, device_fleet_name: Text, output_config: Dict, role_arn: Text = None, description: Text = None, tags: List = None, enable_iot_role_alias: bool = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a device fleet.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        device_fleet_name(Text): The name of the fleet that the device belongs to.
        role_arn(Text, optional): The Amazon Resource Name (ARN) that has access to Amazon Web Services Internet of Things (IoT). Defaults to None.
        description(Text, optional): A description of the fleet. Defaults to None.
        output_config(Dict): The output configuration for storing sample data collected by the fleet.
        tags(List, optional): Creates tags for the specified fleet. Defaults to None.
        enable_iot_role_alias(bool, optional): Whether to create an Amazon Web Services IoT Role Alias during device fleet creation. The name
            of the role alias generated will match this pattern: "SageMakerEdge-{DeviceFleetName}". For
            example, if your device fleet is called "demo-fleet", the name of the role alias will be
            "SageMakerEdge-demo-fleet". Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.sagemaker.device_fleet.present:
                - name: value
                - device_fleet_name: value
                - output_config: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sagemaker.device_fleet.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.sagemaker.describe_device_fleet(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.sagemaker.create_device_fleet(
                ctx,
                
                
                **{"DeviceFleetName": device_fleet_name, "RoleArn": role_arn, "Description": description, "OutputConfig": output_config, "Tags": tags, "EnableIotRoleAlias": enable_iot_role_alias}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.sagemaker.describe_device_fleet(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, device_fleet_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a fleet.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        device_fleet_name(Text): The name of the fleet to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.sagemaker.device_fleet.absent:
                - name: value
                - device_fleet_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sagemaker.device_fleet.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.sagemaker.describe_device_fleet(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.sagemaker.delete_device_fleet(
                ctx,
                
                
                **{"DeviceFleetName": device_fleet_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.sagemaker.describe_device_fleet(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

