"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.sagemaker.delete_model_package_group_policy
hub.exec.boto3.client.sagemaker.get_model_package_group_policy
hub.exec.boto3.client.sagemaker.put_model_package_group_policy
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, model_package_group_name: Text, resource_policy: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Adds a resouce policy to control access to a model group. For information about resoure policies, see Identity-
    based policies and resource-based policies in the Amazon Web Services Identity and Access Management User
    Guide..

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        model_package_group_name(Text): The name of the model group to add a resource policy to.
        resource_policy(Text): The resource policy for the model group.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.sagemaker.model_package_group_policy.present:
                - name: value
                - model_package_group_name: value
                - resource_policy: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sagemaker.model_package_group_policy.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.sagemaker.get_model_package_group_policy(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.sagemaker.put_model_package_group_policy(
                ctx,
                
                
                **{"ModelPackageGroupName": model_package_group_name, "ResourcePolicy": resource_policy}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.sagemaker.get_model_package_group_policy(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, model_package_group_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a model group resource policy.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        model_package_group_name(Text): The name of the model group for which to delete the policy.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.sagemaker.model_package_group_policy.absent:
                - name: value
                - model_package_group_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sagemaker.model_package_group_policy.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.sagemaker.get_model_package_group_policy(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.sagemaker.delete_model_package_group_policy(
                ctx,
                
                
                **{"ModelPackageGroupName": model_package_group_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.sagemaker.get_model_package_group_policy(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

