"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.schemas.create_discoverer
hub.exec.boto3.client.schemas.delete_discoverer
hub.exec.boto3.client.schemas.describe_discoverer
hub.exec.boto3.client.schemas.list_discoverers
hub.exec.boto3.client.schemas.start_discoverer
hub.exec.boto3.client.schemas.stop_discoverer
hub.exec.boto3.client.schemas.update_discoverer
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, source_arn: Text, description: Text = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a discoverer.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        description(Text, optional): A description for the discoverer. Defaults to None.
        source_arn(Text): The ARN of the event bus.
        tags(Dict, optional): Tags associated with the resource. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.schemas.discoverer.present:
                - name: value
                - source_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.schemas.discoverer.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.schemas.describe_discoverer(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.schemas.create_discoverer(
                ctx,
                
                
                **{"Description": description, "SourceArn": source_arn, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.schemas.describe_discoverer(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, discoverer_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a discoverer.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        discoverer_id(Text): The ID of the discoverer.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.schemas.discoverer.absent:
                - name: value
                - discoverer_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.schemas.discoverer.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.schemas.describe_discoverer(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.schemas.delete_discoverer(
                ctx,
                
                
                **{"DiscovererId": discoverer_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.schemas.describe_discoverer(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

