"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.schemas.create_registry
hub.exec.boto3.client.schemas.delete_registry
hub.exec.boto3.client.schemas.describe_registry
hub.exec.boto3.client.schemas.list_registries
hub.exec.boto3.client.schemas.update_registry
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, registry_name: Text, description: Text = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a registry.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        description(Text, optional): A description of the registry to be created. Defaults to None.
        registry_name(Text): The name of the registry.
        tags(Dict, optional): Tags to associate with the registry. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.schemas.registry.present:
                - name: value
                - registry_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.schemas.registry.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.schemas.describe_registry(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.schemas.create_registry(
                ctx,
                
                
                **{"Description": description, "RegistryName": registry_name, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.schemas.describe_registry(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, registry_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a Registry.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        registry_name(Text): The name of the registry.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.schemas.registry.absent:
                - name: value
                - registry_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.schemas.registry.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.schemas.describe_registry(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.schemas.delete_registry(
                ctx,
                
                
                **{"RegistryName": registry_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.schemas.describe_registry(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

