"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.schemas.delete_resource_policy
hub.exec.boto3.client.schemas.get_resource_policy
hub.exec.boto3.client.schemas.put_resource_policy
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, policy: Text, registry_name: Text = None, revision_id: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    The name of the policy.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        policy(Text): The resource-based policy.
        registry_name(Text, optional): The name of the registry. Defaults to None.
        revision_id(Text, optional): The revision ID of the policy. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.schemas.resource_policy.present:
                - name: value
                - policy: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.schemas.resource_policy.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.schemas.get_resource_policy(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.schemas.put_resource_policy(
                ctx,
                
                
                **{"Policy": policy, "RegistryName": registry_name, "RevisionId": revision_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.schemas.get_resource_policy(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, registry_name: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Delete the resource-based policy attached to the specified registry.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        registry_name(Text, optional): The name of the registry. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.schemas.resource_policy.absent:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.schemas.resource_policy.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.schemas.get_resource_policy(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.schemas.delete_resource_policy(
                ctx,
                
                
                **{"RegistryName": registry_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.schemas.get_resource_policy(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

