"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.schemas.create_schema
hub.exec.boto3.client.schemas.delete_schema
hub.exec.boto3.client.schemas.describe_schema
hub.exec.boto3.client.schemas.export_schema
hub.exec.boto3.client.schemas.update_schema
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, content: Text, registry_name: Text, schema_name: Text, type_: Text, description: Text = None, tags: Dict = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a schema definition. Inactive schemas will be deleted after two years.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        content(Text): The source of the schema definition.
        description(Text, optional): A description of the schema. Defaults to None.
        registry_name(Text): The name of the registry.
        schema_name(Text): The name of the schema.
        tags(Dict, optional): Tags associated with the schema. Defaults to None.
        type_(Text): The type of schema.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.schemas.schema.present:
                - name: value
                - content: value
                - registry_name: value
                - schema_name: value
                - type_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.schemas.schema.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.schemas.describe_schema(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.schemas.create_schema(
                ctx,
                
                
                **{"Content": content, "Description": description, "RegistryName": registry_name, "SchemaName": schema_name, "Tags": tags, "Type": type_}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.schemas.describe_schema(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, registry_name: Text, schema_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Delete a schema definition.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        registry_name(Text): The name of the registry.
        schema_name(Text): The name of the schema.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.schemas.schema.absent:
                - name: value
                - registry_name: value
                - schema_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.schemas.schema.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.schemas.describe_schema(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.schemas.delete_schema(
                ctx,
                
                
                **{"RegistryName": registry_name, "SchemaName": schema_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.schemas.describe_schema(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

