"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.securityhub.create_action_target
hub.exec.boto3.client.securityhub.delete_action_target
hub.exec.boto3.client.securityhub.describe_action_targets
hub.exec.boto3.client.securityhub.update_action_target
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, description: Text, id_: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a custom action target in Security Hub. You can use custom actions on findings and insights in Security
    Hub to trigger target actions in Amazon CloudWatch Events.

    Args:
        name(Text): The name of the custom action target. Can contain up to 20 characters.
        description(Text): The description for the custom action target.
        id_(Text): The ID for the custom action target. Can contain up to 20 alphanumeric characters.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.securityhub.action_target.present:
                - name: value
                - description: value
                - id_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.securityhub.action_target.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.securityhub.describe_action_targets(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.securityhub.create_action_target(
                ctx,
                
                
                **{"Name": name, "Description": description, "Id": id_}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.securityhub.describe_action_targets(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, action_target_arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a custom action target from Security Hub. Deleting a custom action target does not affect any findings
    or insights that were already sent to Amazon CloudWatch Events using the custom action.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        action_target_arn(Text): The ARN of the custom action target to delete.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.securityhub.action_target.absent:
                - name: value
                - action_target_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.securityhub.action_target.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.securityhub.describe_action_targets(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.securityhub.delete_action_target(
                ctx,
                
                
                **{"ActionTargetArn": action_target_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.securityhub.describe_action_targets(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

