"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ses.create_template
hub.exec.boto3.client.ses.delete_template
hub.exec.boto3.client.ses.get_template
hub.exec.boto3.client.ses.list_templates
hub.exec.boto3.client.ses.update_template
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, template: Dict)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates an email template. Email templates enable you to send personalized email to one or more destinations in
    a single API operation. For more information, see the Amazon SES Developer Guide. You can execute this operation
    no more than once per second.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        template(Dict): The content of the email, composed of a subject line, an HTML part, and a text-only part.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ses.template.present:
                - name: value
                - template: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ses.template.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ses.get_template(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ses.create_template(
                ctx,
                
                
                **{"Template": template}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ses.get_template(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, template_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an email template. You can execute this operation no more than once per second.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        template_name(Text): The name of the template to be deleted.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ses.template.absent:
                - name: value
                - template_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ses.template.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ses.get_template(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ses.delete_template(
                ctx,
                
                
                **{"TemplateName": template_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ses.get_template(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

