"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.sesv2.create_contact_list
hub.exec.boto3.client.sesv2.delete_contact_list
hub.exec.boto3.client.sesv2.get_contact_list
hub.exec.boto3.client.sesv2.list_contact_lists
hub.exec.boto3.client.sesv2.update_contact_list
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, contact_list_name: Text, topics: List = None, description: Text = None, tags: List = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a contact list.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        contact_list_name(Text): The name of the contact list.
        topics(List, optional): An interest group, theme, or label within a list. A contact list can have multiple topics. Defaults to None.
        description(Text, optional): A description of what the contact list is about. Defaults to None.
        tags(List, optional): The tags associated with a contact list. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.sesv2.contact_list.present:
                - name: value
                - contact_list_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sesv2.contact_list.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.sesv2.get_contact_list(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.sesv2.create_contact_list(
                ctx,
                
                
                **{"ContactListName": contact_list_name, "Topics": topics, "Description": description, "Tags": tags}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.sesv2.get_contact_list(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, contact_list_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a contact list and all of the contacts on that list.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        contact_list_name(Text): The name of the contact list.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.sesv2.contact_list.absent:
                - name: value
                - contact_list_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sesv2.contact_list.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.sesv2.get_contact_list(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.sesv2.delete_contact_list(
                ctx,
                
                
                **{"ContactListName": contact_list_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.sesv2.get_contact_list(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

