"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.sesv2.delete_suppressed_destination
hub.exec.boto3.client.sesv2.get_suppressed_destination
hub.exec.boto3.client.sesv2.list_suppressed_destinations
hub.exec.boto3.client.sesv2.put_suppressed_destination
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, email_address: Text, reason: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Adds an email address to the suppression list for your account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        email_address(Text): The email address that should be added to the suppression list for your account.
        reason(Text): The factors that should cause the email address to be added to the suppression list for your
            account.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.sesv2.suppressed_destination.present:
                - name: value
                - email_address: value
                - reason: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sesv2.suppressed_destination.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.sesv2.get_suppressed_destination(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.sesv2.put_suppressed_destination(
                ctx,
                
                
                **{"EmailAddress": email_address, "Reason": reason}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.sesv2.get_suppressed_destination(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, email_address: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Removes an email address from the suppression list for your account.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        email_address(Text): The suppressed email destination to remove from the account suppression list.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.sesv2.suppressed_destination.absent:
                - name: value
                - email_address: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sesv2.suppressed_destination.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.sesv2.get_suppressed_destination(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.sesv2.delete_suppressed_destination(
                ctx,
                
                
                **{"EmailAddress": email_address}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.sesv2.get_suppressed_destination(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

