"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.sms_voice.create_configuration_set
hub.exec.boto3.client.sms_voice.delete_configuration_set
hub.exec.boto3.client.sms_voice.list_configuration_sets
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, configuration_set_name: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Create a new configuration set. After you create the configuration set, you can add one or more event
    destinations to it.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        configuration_set_name(Text, optional): The name that you want to give the configuration set. Defaults to None.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.sms_voice.configuration_set.present:
                - name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sms_voice.configuration_set.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.sms_voice.list_configuration_sets(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.sms_voice.create_configuration_set(
                ctx,
                
                
                **{"ConfigurationSetName": configuration_set_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.sms_voice.list_configuration_sets(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, configuration_set_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes an existing configuration set.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        configuration_set_name(Text): ConfigurationSetName.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.sms_voice.configuration_set.absent:
                - name: value
                - configuration_set_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.sms_voice.configuration_set.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.sms_voice.list_configuration_sets(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.sms_voice.delete_configuration_set(
                ctx,
                
                
                **{"ConfigurationSetName": configuration_set_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.sms_voice.list_configuration_sets(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

