"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ssm.deregister_patch_baseline_for_patch_group
hub.exec.boto3.client.ssm.get_patch_baseline_for_patch_group
hub.exec.boto3.client.ssm.register_patch_baseline_for_patch_group
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, baseline_id: Text, patch_group: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Registers a patch baseline for a patch group.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        baseline_id(Text): The ID of the patch baseline to register with the patch group.
        patch_group(Text): The name of the patch group to be registered with the patch baseline.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ssm.patch_baseline_for_patch_group.present:
                - name: value
                - baseline_id: value
                - patch_group: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ssm.patch_baseline_for_patch_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ssm.get_patch_baseline_for_patch_group(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ssm.register_patch_baseline_for_patch_group(
                ctx,
                
                
                **{"BaselineId": baseline_id, "PatchGroup": patch_group}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ssm.get_patch_baseline_for_patch_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, baseline_id: Text, patch_group: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Removes a patch group from a patch baseline.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        baseline_id(Text): The ID of the patch baseline to deregister the patch group from.
        patch_group(Text): The name of the patch group that should be deregistered from the patch baseline.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ssm.patch_baseline_for_patch_group.absent:
                - name: value
                - baseline_id: value
                - patch_group: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ssm.patch_baseline_for_patch_group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ssm.get_patch_baseline_for_patch_group(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ssm.deregister_patch_baseline_for_patch_group(
                ctx,
                
                
                **{"BaselineId": baseline_id, "PatchGroup": patch_group}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ssm.get_patch_baseline_for_patch_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

