"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.ssm_incidents.delete_resource_policy
hub.exec.boto3.client.ssm_incidents.get_resource_policies
hub.exec.boto3.client.ssm_incidents.put_resource_policy
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, policy: Text, resource_arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Adds a resource policy to the specified response plan.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        policy(Text): Details of the resource policy.
        resource_arn(Text): The Amazon Resource Name (ARN) of the response plan you're adding the resource policy to.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.ssm_incidents.resource_policy.present:
                - name: value
                - policy: value
                - resource_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ssm_incidents.resource_policy.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.ssm_incidents.get_resource_policies(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.ssm_incidents.put_resource_policy(
                ctx,
                
                
                **{"policy": policy, "resourceArn": resource_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.ssm_incidents.get_resource_policies(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, policy_id: Text, resource_arn: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the resource policy that AWS Resource Access Manager uses to share your Incident Manager resource.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        policy_id(Text): The ID of the resource policy you're deleting.
        resource_arn(Text): The Amazon Resource Name (ARN) of the resource you're deleting the policy from.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.ssm_incidents.resource_policy.absent:
                - name: value
                - policy_id: value
                - resource_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.ssm_incidents.resource_policy.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.ssm_incidents.get_resource_policies(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.ssm_incidents.delete_resource_policy(
                ctx,
                
                
                **{"policyId": policy_id, "resourceArn": resource_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.ssm_incidents.get_resource_policies(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

