"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.wellarchitected.associate_lenses
hub.exec.boto3.client.wellarchitected.disassociate_lenses
hub.exec.boto3.client.wellarchitected.list_lenses
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, workload_id: Text, lens_aliases: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Associate a lens to a workload.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        workload_id(Text): The ID assigned to the workload. This ID is unique within an AWS Region.
        lens_aliases(List): List of lens aliases to associate or disassociate with a workload. Identify a lens using its
            LensSummary$LensAlias.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.wellarchitected.lens.present:
                - name: value
                - workload_id: value
                - lens_aliases: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.wellarchitected.lens.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.wellarchitected.list_lenses(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.wellarchitected.associate_lenses(
                ctx,
                
                
                **{"WorkloadId": workload_id, "LensAliases": lens_aliases}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.wellarchitected.list_lenses(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, workload_id: Text, lens_aliases: List)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Disassociate a lens from a workload.  The AWS Well-Architected Framework lens (wellarchitected) cannot be
    removed from a workload.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        workload_id(Text): The ID assigned to the workload. This ID is unique within an AWS Region.
        lens_aliases(List): List of lens aliases to associate or disassociate with a workload. Identify a lens using its
            LensSummary$LensAlias.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.wellarchitected.lens.absent:
                - name: value
                - workload_id: value
                - lens_aliases: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.wellarchitected.lens.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.wellarchitected.list_lenses(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.wellarchitected.disassociate_lenses(
                ctx,
                
                
                **{"WorkloadId": workload_id, "LensAliases": lens_aliases}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.wellarchitected.list_lenses(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

