"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.workdocs.create_folder
hub.exec.boto3.client.workdocs.delete_folder
hub.exec.boto3.client.workdocs.get_folder
hub.exec.boto3.client.workdocs.update_folder
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, parent_folder_id: Text, name: Text = None, authentication_token: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a folder with the specified name and parent folder.

    Args:
        name(Text, optional): The name of the new folder. Defaults to None.
        authentication_token(Text, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to
            access the API. Defaults to None.
        parent_folder_id(Text): The ID of the parent folder.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.workdocs.folder.present:
                - parent_folder_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.workdocs.folder.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.workdocs.get_folder(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.workdocs.create_folder(
                ctx,
                
                
                **{"Name": name, "AuthenticationToken": authentication_token, "ParentFolderId": parent_folder_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.workdocs.get_folder(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, folder_id: Text, authentication_token: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Permanently deletes the specified folder and its contents.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        authentication_token(Text, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to
            access the API. Defaults to None.
        folder_id(Text): The ID of the folder.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.workdocs.folder.absent:
                - name: value
                - folder_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.workdocs.folder.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.workdocs.get_folder(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.workdocs.delete_folder(
                ctx,
                
                
                **{"AuthenticationToken": authentication_token, "FolderId": folder_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.workdocs.get_folder(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

