"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.workdocs.create_notification_subscription
hub.exec.boto3.client.workdocs.delete_notification_subscription
hub.exec.boto3.client.workdocs.describe_notification_subscriptions
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, organization_id: Text, endpoint: Text, protocol: Text, subscription_type: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Configure Amazon WorkDocs to use Amazon SNS notifications. The endpoint receives a confirmation message, and
    must confirm the subscription. For more information, see Subscribe to Notifications in the Amazon WorkDocs
    Developer Guide.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        organization_id(Text): The ID of the organization.
        endpoint(Text): The endpoint to receive the notifications. If the protocol is HTTPS, the endpoint is a URL that
            begins with https.
        protocol(Text): The protocol to use. The supported value is https, which delivers JSON-encoded messages using
            HTTPS POST.
        subscription_type(Text): The notification type.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.workdocs.notification_subscription.present:
                - name: value
                - organization_id: value
                - endpoint: value
                - protocol: value
                - subscription_type: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.workdocs.notification_subscription.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.workdocs.describe_notification_subscriptions(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.workdocs.create_notification_subscription(
                ctx,
                
                
                **{"OrganizationId": organization_id, "Endpoint": endpoint, "Protocol": protocol, "SubscriptionType": subscription_type}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.workdocs.describe_notification_subscriptions(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, subscription_id: Text, organization_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the specified subscription from the specified organization.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        subscription_id(Text): The ID of the subscription.
        organization_id(Text): The ID of the organization.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.workdocs.notification_subscription.absent:
                - name: value
                - subscription_id: value
                - organization_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.workdocs.notification_subscription.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.workdocs.describe_notification_subscriptions(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.workdocs.delete_notification_subscription(
                ctx,
                
                
                **{"SubscriptionId": subscription_id, "OrganizationId": organization_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.workdocs.describe_notification_subscriptions(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

