"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.worklink.associate_domain
hub.exec.boto3.client.worklink.describe_domain
hub.exec.boto3.client.worklink.disassociate_domain
hub.exec.boto3.client.worklink.list_domains
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, fleet_arn: Text, domain_name: Text, acm_certificate_arn: Text, display_name: Text = None)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Specifies a domain to be associated to Amazon WorkLink.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        fleet_arn(Text): The Amazon Resource Name (ARN) of the fleet.
        domain_name(Text): The fully qualified domain name (FQDN).
        display_name(Text, optional): The name to display. Defaults to None.
        acm_certificate_arn(Text): The ARN of an issued ACM certificate that is valid for the domain being associated.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.worklink.domain.present:
                - name: value
                - fleet_arn: value
                - domain_name: value
                - acm_certificate_arn: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.worklink.domain.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.worklink.describe_domain(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.worklink.associate_domain(
                ctx,
                
                
                **{"FleetArn": fleet_arn, "DomainName": domain_name, "DisplayName": display_name, "AcmCertificateArn": acm_certificate_arn}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.worklink.describe_domain(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, fleet_arn: Text, domain_name: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Disassociates a domain from Amazon WorkLink. End users lose the ability to access the domain with Amazon
    WorkLink.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        fleet_arn(Text): The ARN of the fleet.
        domain_name(Text): The name of the domain.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.worklink.domain.absent:
                - name: value
                - fleet_arn: value
                - domain_name: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.worklink.domain.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.worklink.describe_domain(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.worklink.disassociate_domain(
                ctx,
                
                
                **{"FleetArn": fleet_arn, "DomainName": domain_name}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.worklink.describe_domain(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

