"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.workmail.create_group
hub.exec.boto3.client.workmail.delete_group
hub.exec.boto3.client.workmail.describe_group
hub.exec.boto3.client.workmail.list_groups
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, organization_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a group that can be used in Amazon WorkMail by calling the RegisterToWorkMail operation.

    Args:
        name(Text): The name of the group.
        organization_id(Text): The organization under which the group is to be created.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.workmail.group.present:
                - name: value
                - organization_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.workmail.group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.workmail.describe_group(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.workmail.create_group(
                ctx,
                
                
                **{"Name": name, "OrganizationId": organization_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.workmail.describe_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, organization_id: Text, group_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a group from Amazon WorkMail.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        organization_id(Text): The organization that contains the group.
        group_id(Text): The identifier of the group to be deleted.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.workmail.group.absent:
                - name: value
                - organization_id: value
                - group_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.workmail.group.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.workmail.describe_group(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.workmail.delete_group(
                ctx,
                
                
                **{"OrganizationId": organization_id, "GroupId": group_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.workmail.describe_group(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

