"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.workmail.create_resource
hub.exec.boto3.client.workmail.delete_resource
hub.exec.boto3.client.workmail.describe_resource
hub.exec.boto3.client.workmail.list_resources
hub.exec.boto3.client.workmail.tag_resource
hub.exec.boto3.client.workmail.untag_resource
hub.exec.boto3.client.workmail.update_resource
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, organization_id: Text, type_: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a new Amazon WorkMail resource.

    Args:
        name(Text): The name of the new resource.
        organization_id(Text): The identifier associated with the organization for which the resource is created.
        type_(Text): The type of the new resource. The available types are equipment and room.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.workmail.resource.present:
                - name: value
                - organization_id: value
                - type_: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.workmail.resource.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.workmail.describe_resource(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.workmail.create_resource(
                ctx,
                
                
                **{"Name": name, "OrganizationId": organization_id, "Type": type_}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.workmail.describe_resource(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, organization_id: Text, resource_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes the specified resource.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        organization_id(Text): The identifier associated with the organization from which the resource is deleted.
        resource_id(Text): The identifier of the resource to be deleted.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.workmail.resource.absent:
                - name: value
                - organization_id: value
                - resource_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.workmail.resource.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.workmail.describe_resource(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.workmail.delete_resource(
                ctx,
                
                
                **{"OrganizationId": organization_id, "ResourceId": resource_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.workmail.describe_resource(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

