"""
Autogenerated state module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__

hub.exec.boto3.client.workmail.create_user
hub.exec.boto3.client.workmail.delete_user
hub.exec.boto3.client.workmail.describe_user
hub.exec.boto3.client.workmail.list_users
"""



from typing import *
import dict_tools.differ as differ
async def present(hub, ctx, name: Text, organization_id: Text, display_name: Text, password: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Creates a user who can be used in Amazon WorkMail by calling the RegisterToWorkMail operation.

    Args:
        name(Text): The name for the new user. WorkMail directory user names have a maximum length of 64. All others
            have a maximum length of 20.
        organization_id(Text): The identifier of the organization for which the user is created.
        display_name(Text): The display name for the new user.
        password(Text): The password for the new user.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_present:
              aws_auto.workmail.user.present:
                - name: value
                - organization_id: value
                - display_name: value
                - password: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.workmail.user.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    
    before = await hub.exec.boto3.client.workmail.describe_user(name)

    if before:
        result["comment"] = f"'{name}' already exists"
    else:
        try:
            ret = await hub.exec.boto3.client.workmail.create_user(
                ctx,
                
                
                **{"Name": name, "OrganizationId": organization_id, "DisplayName": display_name, "Password": password}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            ret["comment"] = f"Created '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    
    # TODO perform other modifications as needed here
    ...

    after = await hub.exec.boto3.client.workmail.describe_user(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

async def absent(hub, ctx, name: Text, organization_id: Text, user_id: Text)  -> Dict[str, Any]:
    r'''
    **Autogenerated function**
    
    Deletes a user from Amazon WorkMail and all subsequent systems. Before you can delete a user, the user state
    must be DISABLED. Use the DescribeUser action to confirm the user state. Deleting a user is permanent and cannot
    be undone. WorkMail archives user mailboxes for 30 days before they are permanently removed.

    Args:
        name(Text): A name, ID, or JMES search path to identify the resource.
        organization_id(Text): The organization that contains the user to be deleted.
        user_id(Text): The identifier of the user to be deleted.

    Returns:
        Dict[str, Any]

    Examples:

        .. code-block:: sls

            resource_is_absent:
              aws_auto.workmail.user.absent:
                - name: value
                - organization_id: value
                - user_id: value
    '''
    
    result = dict(comment="", changes= None, name=name, result=True)
    ret = await hub.exec.boto3.client.workmail.user.id(
        ctx,
        jmes_path=name
    )
    if ret["status"]:
        # name is now the first id that matched the JMES search path
        name = ret["ret"]
    

    

    before = await hub.exec.boto3.client.workmail.describe_user(name)

    if not before:
        result["comment"] = f"'{name}' already absent"
    else:
        try:
            ret = await hub.exec.boto3.client.workmail.delete_user(
                ctx,
                
                
                **{"OrganizationId": organization_id, "UserId": user_id}
            )
            result["result"] = ret["status"]
            if not result["result"]:
                result["comment"] = ret["comment"]
                return result
            result["comment"] = f"Deleted '{name}'"
        except hub.tool.boto3.exception.ClientError as e:
            result["comment"] = f"{e.__class__.__name__}: {e}"

    

    after = await hub.exec.boto3.client.workmail.describe_user(name)
    result["changes"] = differ.deep_diff(before, after)
    return result

